@@ -24,12 +24,12 @@ else{
 		elseif (isset($protectedPost['ADMIN']) and $protectedPost['ADMIN'] == 'ADMIN' and isset($_SESSION['OCS']['ADMIN']['ACCOUNTINFO']))
 			unset($_SESSION['OCS']['ADMIN']['ACCOUNTINFO']);
 		
-		if ($_SESSION['OCS']['CONFIGURATION']['ACCOUNTINFO'] == 'YES' and isset($_SESSION['OCS']['ADMIN']['ACCOUNTINFO']))
+		if ($_SESSION['OCS']['profile']->getConfigValue('ACCOUNTINFO') == 'YES' and isset($_SESSION['OCS']['ADMIN']['ACCOUNTINFO']))
 			$admin_accountinfo=true;
 			
 		$list_tab=find_all_account_tab('TAB_ACCOUNTAG','COMPUTERS',1);	
 		if ($list_tab != ''){
-			if ($protectedPost['Valid_modif_x'] != ""){
+			if ($protectedPost['Valid_modif'] != ""){
 				
 				if (!isset($protectedPost['onglet']) or $protectedPost['onglet'] == '' or ! is_numeric($protectedPost['onglet']))
 					$protectedPost['onglet'] = $list_tab['FIRST'];
@@ -39,7 +39,7 @@ else{
 				
 				$res_admin_info = mysql2_query_secure($sql_admin_info, $_SESSION['OCS']["readServer"], $arg_admin_info);
 				
-				while ( $val_admin_info = mysql_fetch_array($res_admin_info) ) {
+				while ( $val_admin_info = mysqli_fetch_array($res_admin_info) ) {
 					if ($val_admin_info['NAME_ACCOUNTINFO']) {
 						$data_fields_account[$val_admin_info['NAME_ACCOUNTINFO']] = "";
 					} else {
@@ -78,13 +78,11 @@ else{
 						update_accountinfo_config($new_order['NEW'],array('SHOW_ORDER'=>$new_order['OLD_VALUE']));
 					}
 				}
-			
-			//print_r($info_account_id);
 			if (!isset($protectedPost['onglet']) or $protectedPost['onglet'] =='' or !is_numeric($protectedPost['onglet']))
 				 $protectedPost['onglet'] = $list_tab['FIRST'];
 			unset($list_tab['FIRST']);
 			
-			echo "<br>".open_form($form_name);
+			echo open_form($form_name);
 			if (!$show_all_column){
 				onglet($list_tab,$form_name,"onglet",6);
 				$sql_admin_info="select ID,TYPE,NAME,COMMENT,NAME_ACCOUNTINFO,SHOW_ORDER,DEFAULT_VALUE from accountinfo_config where ID_TAB = %s and account_type='COMPUTERS'
@@ -95,8 +93,8 @@ else{
 								order by SHOW_ORDER ASC";
 				$arg_admin_info=array('COMPUTERS');		
 			}
-			echo '<div class="mlt_bordure" >';
-			if ($_SESSION['OCS']['CONFIGURATION']['ACCOUNTINFO'] == 'YES' and !$show_all_column){
+			echo '<div class="form-frame">';
+			if ($_SESSION['OCS']['profile']->getConfigValue('ACCOUNTINFO') == 'YES' and !$show_all_column){
 				$show_admin_button = "<a href=# OnClick='pag(\"ADMIN\",\"ADMIN\",\"".$form_name."\");'>";
 				if (isset($_SESSION['OCS']['ADMIN']['ACCOUNTINFO']))
 					$show_admin_button .= "<img src=image/success.png></a>";
@@ -107,23 +105,23 @@ else{
 				$show_admin_button='';
 				
 			$res_admin_info=mysql2_query_secure($sql_admin_info,$_SESSION['OCS']["readServer"],$arg_admin_info);
-			$num_row=mysql_num_rows($res_admin_info);
+			$num_row=mysqli_num_rows($res_admin_info);
 			$name_field=array();
 			$tab_name=array();
 			$type_field=array();
 			$value_field=array();
-			$config['COMMENT_BEHING']=array();
+			$config['COMMENT_AFTER']=array();
 			$config['SELECT_DEFAULT']=array();
 			$config['JAVASCRIPT']=array();
 			$config['SIZE']=array();
 			$config['DDE']=array();
 			
 			$nb_row=1;
-			while ($val_admin_info = mysql_fetch_array( $res_admin_info )){	
+			while ($val_admin_info = mysqli_fetch_array( $res_admin_info )){	
 				array_push($config['DDE'],$systemid);	
 				//if name_accountinfo is not null 
 				//column name in accountinfo table is name_accountinfo 
-				//functionnality for compatibily with older version of OCS
+				//functionality for compatibility with older version of OCS
 				//we can't change the name TAG in accountinfo table 
 				if ($val_admin_info['NAME_ACCOUNTINFO'] != '')
 					$name_accountinfo=trim($val_admin_info['NAME_ACCOUNTINFO']);
@@ -143,9 +141,9 @@ else{
 						array_push($config['JAVASCRIPT'],'');
 						array_push($config['SIZE'],'');
 						if ($admin_accountinfo)
-							array_push($config['COMMENT_BEHING'],$up_png . "<a href=# onclick=window.open(\"index.php?".PAG_INDEX."=".$pages_refs['ms_adminvalues']."&head=1&tag=ACCOUNT_VALUE_" . $val_admin_info['NAME'] . "\",\"ACCOUNT_VALUE\",\"location=0,status=0,scrollbars=0,menubar=0,resizable=0,width=550,height=450\")><img src=image/plus.png></a>");
+							array_push($config['COMMENT_AFTER'],$up_png . "<a href=# href=\"index.php?".PAG_INDEX."=".$pages_refs['ms_adminvalues']."&head=1&tag=ACCOUNT_VALUE_" . $val_admin_info['NAME'] . "\"><img src=image/plus.png></a>");
 						else
-							array_push($config['COMMENT_BEHING'],'');
+							array_push($config['COMMENT_AFTER'],'');
 						array_push($config['SELECT_DEFAULT'],'YES');
 						$field_select_values=find_value_field("ACCOUNT_VALUE_".$val_admin_info['NAME']);
 						
@@ -156,7 +154,7 @@ else{
 							$i=0;
 							$tp_readonly="";
 							while (isset($temp_val[$i]) and $temp_val[$i] != ''){
-								if ($_SESSION['OCS']['CONFIGURATION']['CHANGE_ACCOUNTINFO'] == "YES"){			
+								if ($_SESSION['OCS']['profile']->getConfigValue('CHANGE_ACCOUNTINFO') == "YES"){			
 									$protectedPost[$name_accountinfo . '_' . $temp_val[$i]]='on';
 								}else{
 									$tp_readonly .= $field_select_values[$temp_val[$i]].";";
@@ -171,7 +169,7 @@ else{
 							}
 						}else{
 							$protectedPost[$name_accountinfo]=$info_account_id[$name_accountinfo];
-							if ($_SESSION['OCS']['CONFIGURATION']['CHANGE_ACCOUNTINFO'] == "YES")
+							if ($_SESSION['OCS']['profile']->getConfigValue('CHANGE_ACCOUNTINFO') == "YES")
 								array_push($value_field,$field_select_values);
 							else
 								array_push($value_field,$field_select_values[$protectedPost[$name_accountinfo]]);
@@ -179,11 +177,11 @@ else{
 							
 					}elseif ($val_admin_info['TYPE'] == 6){	
 						array_push($value_field,$info_account_id[$name_accountinfo]);
-						if ($_SESSION['OCS']['CONFIGURATION']['CHANGE_ACCOUNTINFO'] == "YES"){
+						if ($_SESSION['OCS']['profile']->getConfigValue('CHANGE_ACCOUNTINFO') == "YES"){
 							if ($admin_accountinfo)
-								array_push($config['COMMENT_BEHING'],$up_png . datePick($name_accountinfo));
+								array_push($config['COMMENT_AFTER'],$up_png . datePick($name_accountinfo));
 							else
-								array_push($config['COMMENT_BEHING'],datePick($name_accountinfo));
+								array_push($config['COMMENT_AFTER'],datePick($name_accountinfo));
 							array_push($config['JAVASCRIPT'],"READONLY ".dateOnClick($name_accountinfo));
 							array_push($config['SELECT_DEFAULT'],'');
 							array_push($config['SIZE'],'8');	
@@ -191,9 +189,9 @@ else{
 					}elseif ($val_admin_info['TYPE'] == 5){
 						array_push($value_field,"accountinfo");
 						if ($admin_accountinfo)
-							array_push($config['COMMENT_BEHING'],$up_png);
+							array_push($config['COMMENT_AFTER'],$up_png);
 						else
-							array_push($config['COMMENT_BEHING'],"");
+							array_push($config['COMMENT_AFTER'],"");
 						array_push($config['SELECT_DEFAULT'],'');
 						array_push($config['JAVASCRIPT'],'');
 						array_push($config['SIZE'],'');
@@ -202,21 +200,20 @@ else{
 						array_push($value_field,$info_account_id[$name_accountinfo]);
 						if ($admin_accountinfo){
 							
-							array_push($config['COMMENT_BEHING'],$up_png);
+							array_push($config['COMMENT_AFTER'],$up_png);
 						}else
-							array_push($config['COMMENT_BEHING'],"");
+							array_push($config['COMMENT_AFTER'],"");
 						
 						array_push($config['SELECT_DEFAULT'],"index.php?".PAG_INDEX."=".$pages_refs['ms_qrcode']."&no_header=1&default_value=".$val_admin_info['DEFAULT_VALUE']."&systemid=".$protectedGet['systemid']);
 						array_push($config['JAVASCRIPT'],"onclick=window.open(\"index.php?".PAG_INDEX."=".$pages_refs['ms_qrcode']."&no_header=1&default_value=".$val_admin_info['DEFAULT_VALUE']."&systemid=".$protectedGet['systemid']."\")");
 						array_push($config['SIZE'],'width=80 height=80');
 						
-						
-					}else{
+						}else{
 						array_push($value_field,$info_account_id[$name_accountinfo]);
 						if ($admin_accountinfo)
-							array_push($config['COMMENT_BEHING'],$up_png);
+							array_push($config['COMMENT_AFTER'],$up_png);
 						else
-							array_push($config['COMMENT_BEHING'],"");
+							array_push($config['COMMENT_AFTER'],"");
 						array_push($config['SELECT_DEFAULT'],'');
 						array_push($config['JAVASCRIPT'],'');
 						array_push($config['SIZE'],'');
@@ -224,7 +221,7 @@ else{
 					
 					array_push($name_field,$name_accountinfo);
 					array_push($tab_name,$val_admin_info['COMMENT']);
-					if ($_SESSION['OCS']['CONFIGURATION']['CHANGE_ACCOUNTINFO'] == "YES")
+					if ($_SESSION['OCS']['profile']->getConfigValue('CHANGE_ACCOUNTINFO') == "YES")
 						array_push($type_field,$convert_type[$val_admin_info['TYPE']]);
 					else
 						array_push($type_field,3);
@@ -233,7 +230,7 @@ else{
 				$nb_row++;
 			}	
 				$tab_typ_champ=show_field($name_field,$type_field,$value_field,$config);
-				if ($_SESSION['OCS']['CONFIGURATION']['ACCOUNTINFO'] == 'YES')
+				if ($_SESSION['OCS']['profile']->getConfigValue('ACCOUNTINFO') == 'YES')
 					$tab_hidden=array('ADMIN'=>'','UP'=>'','DOWN'=>'');
 				//echo "<input type='hidden' name='ADMIN' id='ADMIN' value=''>";
 				if ($show_all_column or $admin_accountinfo)
@@ -241,11 +238,16 @@ else{
 				else
 					$showbutton=true;
 				
-				if ($_SESSION['OCS']['CONFIGURATION']['CHANGE_ACCOUNTINFO'] != "YES")
+				if ($_SESSION['OCS']['profile']->getConfigValue('CHANGE_ACCOUNTINFO') != "YES")
 					$showbutton=false;
-				tab_modif_values($tab_name,$tab_typ_champ,$tab_hidden,$title="",$comment="",$name_button="modif",$showbutton,$form_name='NO_FORM',$show_admin_button);
+				tab_modif_values($tab_name,$tab_typ_champ,$tab_hidden, array(
+					'show_button' => $showbutton,
+					'form_name' => $form_name='NO_FORM',
+					'top_action' => $show_admin_button,
+					'show_frame' => false
+				));
 			
-			echo "</div>"; 
+			echo '</div>';
 			echo close_form();
 		}
 }
