@@ -18,7 +18,7 @@ if (isset($protectedGet['reset_notified']) and is_numeric($protectedGet['reset_n
 
 
 //affect again a packet
-if ($protectedPost['Valid_modif_x']){
+if ($protectedPost['Valid_modif']){
 	if (trim($protectedPost['MOTIF'])){
 		if ($protectedPost["ACTION"] == "again"){
 			//delete all info of specific teledeploy
@@ -29,7 +29,7 @@ if ($protectedPost['Valid_modif_x']){
 		}
 		mysql2_query_secure($sql, $_SESSION['OCS']["writeServer"],$arg);
 		
-		if (mysql_affected_rows() != 0){
+		if (mysqli_affected_rows($_SESSION['OCS']["writeServer"]) != 0){
 			$sql="INSERT INTO itmgmt_comments (hardware_id,comments,user_insert,date_insert,action) 
 					values ('%s','%s','%s',%s,'%s => %s')"; 
 			$arg=array($systemid,$protectedPost['MOTIF'],$_SESSION['OCS']["loggeduser"],
@@ -40,7 +40,7 @@ if ($protectedPost['Valid_modif_x']){
 		 msg_error($l->g(903));
 }
 
-if ($protectedPost['Reset_modif_x'])
+if ($protectedPost['Reset_modif'])
 unset($protectedGet['affect_again'],$protectedGet['affect_reset']);
 
 
@@ -62,19 +62,21 @@ if ($protectedGet['affect_again'] or $protectedGet['affect_reset']){
           where de.id='%s' and de.FILEID=da.FILEID
 			and d.IVALUE=de.ID
 			AND d.hardware_id='%s' AND d.name='%s'
-			and tvalue like '%s'";
-	$arg=array($id_pack_affect,$protectedGet['systemid'],"DOWNLOAD","ERR_%");		
+			and (tvalue like '%s' or tvalue like '%s') ";
+	$arg=array($id_pack_affect,$protectedGet['systemid'],"DOWNLOAD","ERR_%","EXIT_CODE%");		
 	$res = mysql2_query_secure( $sql, $_SESSION['OCS']["readServer"],$arg );
-		$val = mysql_fetch_array( $res ); 
+		$val = mysqli_fetch_array( $res ); 
 	if (isset($val['name'])){		
 		$tab_typ_champ[0]['INPUT_NAME']="MOTIF";
 		$tab_typ_champ[0]['INPUT_TYPE']=1;
 		$data_form[0]="<center>".$lbl_action."</center>";
-		tab_modif_values($data_form,$tab_typ_champ,array('NAME_PACK'=>$val['name'],'ACTION'=>$hidden_action),$title_action.$val['name'],"");
+		tab_modif_values($data_form,$tab_typ_champ,array('NAME_PACK'=>$val['name'],'ACTION'=>$hidden_action), array(
+			'title' => $title_action.$val['name']
+		));
 
 	}
 }
-if( isset( $protectedGet["suppack"] ) &  $_SESSION['OCS']['CONFIGURATION']['TELEDIFF']=="YES" ) {
+if( isset( $protectedGet["suppack"] ) &  $_SESSION['OCS']['profile']->getConfigValue('TELEDIFF')=="YES" ) {
 	
 	if( $_SESSION['OCS']["justAdded"] == false ){
 		desactive_packet($systemid,$protectedGet["suppack"]);
@@ -91,10 +93,10 @@ if( isset( $protectedGet["actgrp"] )) {
 					  FROM hardware h 
 					  WHERE h.deviceid='_SYSTEMGROUP_' ";
 		//If you hav'nt permission => see only visible groups
-		if (!($_SESSION['OCS']['CONFIGURATION']['GROUPS']=="YES"))
+		if (!($_SESSION['OCS']['profile']->getConfigValue('GROUPS')=="YES"))
 			$reqGroups .= " and h.workgroup = 'GROUP_4_ALL'";
 		$resGroups = mysql2_query_secure( $reqGroups, $_SESSION['OCS']["readServer"] );
-		$valGroups = mysql_fetch_array( $resGroups ); 
+		$valGroups = mysqli_fetch_array( $resGroups ); 
 		if (isset($valGroups['id'])){
 			$reqDelete = "DELETE FROM groups_cache WHERE hardware_id=%s AND group_id=%s";
 			
@@ -124,7 +126,7 @@ $i=0;
 	echo "<table BORDER='1' WIDTH = '95%' ALIGN = 'Center' CELLPADDING='0' BGCOLOR='#C7D9F5' BORDERCOLOR='#9894B5'>";
 	
 	
-	while($item=mysql_fetch_array($resultDetails,MYSQL_ASSOC)) {
+	while($item=mysqli_fetch_array($resultDetails,MYSQL_ASSOC)) {
 		$optPerso[ $item["NAME"] ][ "IVALUE" ] = $item["IVALUE"];
 		$optPerso[ $item["NAME"] ][ "TVALUE" ] = $item["TVALUE"];
 	}	
@@ -148,8 +150,8 @@ $i=0;
 		echo $td3.$l->g(493)."</td>";
 	}
 	//Can you modify configuration of this computer?
-	if( $_SESSION['OCS']['CONFIGURATION']['CONFIG']=="YES" ){
-		echo "<td align=center rowspan=8><a href=# Onclick=window.open(\"index.php?".PAG_INDEX."=".$pages_refs['ms_custom_param']."&head=1&idchecked=".$systemid."&origine=machine\",\"rollo\",\"location=0,status=0,scrollbars=1,menubar=0,resizable=0,width=800,height=500\");>
+	if( $_SESSION['OCS']['profile']->getConfigValue('CONFIG')=="YES" ){
+		echo "<td align=center rowspan=8><a href=\"index.php?".PAG_INDEX."=".$pages_refs['ms_custom_param']."&head=1&idchecked=".$systemid."&origine=machine\" >
 		<img src='image/modif_a.png' title='".$l->g(285)."'></a></td></tr>";
 	}
 	$ii++; $td3 = $ii%2==0?$td2:$td4;
@@ -225,13 +227,13 @@ $i=0;
 	$arg_groups=$systemid;
 	$resGroups = mysql2_query_secure($sql_groups, $_SESSION['OCS']["readServer"],$arg_groups); 
 	echo "<tr><td colspan=100></td></tr>";
-	if( mysql_num_rows( $resGroups )>0 ) {
-		while( $valGroups = mysql_fetch_array( $resGroups ) ) {
+	if( mysqli_num_rows( $resGroups )>0 ) {
+		while( $valGroups = mysqli_fetch_array( $resGroups ) ) {
 			$ii++; $td3 = $ii%2==0?$td2:$td4;
 			echo "<tr>";
 			echo "<td bgcolor='white' align='center' valign='center'>&nbsp;</td>";
 			echo $td3.$l->g(607)." ";		
-			if( $_SESSION['OCS']['CONFIGURATION']['GROUPS']=="YES" || $valGroups["workgroup"]=="GROUP_4_ALL")
+			if( $_SESSION['OCS']['profile']->getConfigValue('GROUPS')=="YES" || $valGroups["workgroup"]=="GROUP_4_ALL")
 				echo "<a href='index.php?".PAG_INDEX."=".$pages_refs['ms_group_show']."&head=1&systemid=".$valGroups["group_id"]."' target='_blank'>".$valGroups["name"]."</td>";
 			else
 				echo "<b>".$valGroups["name"]."</b></td>";			
@@ -243,7 +245,7 @@ $i=0;
 				case 2: echo "<font color='red'>".$l->g(597)."</font></td>"; break;
 			}
 			
-			if( $_SESSION['OCS']['CONFIGURATION']['GROUPS']=="YES" || $valGroups["workgroup"]=="GROUP_4_ALL") {
+			if( $_SESSION['OCS']['profile']->getConfigValue('GROUPS')=="YES" || $valGroups["workgroup"]=="GROUP_4_ALL") {
 				$hrefBase = "index.php?".PAG_INDEX."=".$pages_refs['ms_computer']."&head=1&systemid=".urlencode($systemid)."&option=cd_configuration&grp=".$valGroups["group_id"];
 				switch( $valGroups["static"] ) {
 					case 0: echo $td3."<a href='$hrefBase&actgrp=1'>".$l->g(598)."</a>&nbsp; &nbsp; &nbsp;<a href='$hrefBase&actgrp=2'>".$l->g(600)."</a></td>"; break;
@@ -262,19 +264,19 @@ $i=0;
 		$hrefBase = "index.php?".PAG_INDEX."=".$pages_refs['ms_computer']."&head=1&systemid=".urlencode($systemid)."&option=cd_configuration";
 		
 		echo "<tr><td colspan='10' align='right'>";
-		if( $_SESSION['OCS']['CONFIGURATION']['TELEDIFF']=="YES" ) 
-			echo "<a href=# Onclick=window.open(\"index.php?".PAG_INDEX."=".$pages_refs['ms_custom_pack']."&head=1&idchecked=".$systemid."&origine=mach\",\"rollo\",\"location=0,status=0,scrollbars=1,menubar=0,resizable=0,width=800,height=500\");>".$l->g(501)."</a> ";
+		if( $_SESSION['OCS']['profile']->getConfigValue('TELEDIFF')=="YES" ) 
+			echo "<a href=\"index.php?".PAG_INDEX."=".$pages_refs['ms_custom_pack']."&head=1&idchecked=".$systemid."&origine=mach\">".$l->g(501)."</a> ";
 		
 	
 		$reqGroups = "SELECT h.name,h.id,h.workgroup 
 					  FROM hardware h,groups g 
 					  WHERE  g.hardware_id=h.id  and h.deviceid='_SYSTEMGROUP_'";
-		if( !($_SESSION['OCS']['CONFIGURATION']['GROUPS']=="YES") )
+		if( !($_SESSION['OCS']['profile']->getConfigValue('GROUPS')=="YES") )
 			$reqGroups .= " and workgroup = 'GROUP_4_ALL'";
 		$reqGroups .= " order by h.name";
 		$resGroups =mysql2_query_secure( $reqGroups, $_SESSION['OCS']["readServer"] );
 		$first = true;
-		while( $valGroups = mysql_fetch_array( $resGroups ) ) {
+		while( $valGroups = mysqli_fetch_array( $resGroups ) ) {
 			if( $first ) {
 				echo $l->g(386)." <a href=# OnClick=window.location='$hrefBase&actgrp=1&grp='+document.getElementById(\"groupcombo\").options[document.getElementById(\"groupcombo\").selectedIndex].value>".
 				$l->g(589)."</a>";
@@ -289,6 +291,6 @@ $i=0;
 			
 		echo "</td></tr>";		
 	//}
-	echo "</table><br>";
+	echo "</table>";
 	echo close_form();
 ?>
