@@ -8,12 +8,26 @@
 // code is always made freely available.
 // Please refer to the General Public Licence http://www.gnu.org/ or Licence.txt
 //====================================================================================
+if(AJAX){
+	parse_str($protectedPost['ocs']['0'], $params);
+	$protectedPost+=$params;
+
+	ob_start();
+	$ajax = true;
+}
+else{
+	$ajax=false;
+}
+
 
 print_item_header($l->g(93));
 	if (!isset($protectedPost['SHOW']))
 		$protectedPost['SHOW'] = 'NOSHOW';
 	$form_name="affich_controllers";
 	$table_name=$form_name;
+	$tab_options=$protectedPost;
+	$tab_options['form_name']=$form_name;
+	$tab_options['table_name']=$table_name;
 	echo open_form($form_name);
 	$list_fields=array($l->g(64) => 'MANUFACTURER',
 			   $l->g(49) => 'NAME',
@@ -33,7 +47,13 @@ print_item_header($l->g(93));
 			$queryDetails .= $value.",";		
 	}
 	$queryDetails  = substr($queryDetails,0,-1)." FROM controllers WHERE (hardware_id=$systemid)";
-	tab_req($table_name,$list_fields,$default_fields,$list_col_cant_del,$queryDetails,$form_name,80,$tab_options);
+	ajaxtab_entete_fixe($list_fields,$default_fields,$tab_options,$list_col_cant_del);
+	
 	echo close_form();
+	if ($ajax){
+		ob_end_clean();
+		tab_req($list_fields,$default_fields,$list_col_cant_del,$queryDetails,$tab_options);
+		ob_start();
+	}
 
 ?>
\ No newline at end of file
