@@ -16,10 +16,21 @@
  * 
  * 
  */
-
+	if(AJAX){
+		parse_str($protectedPost['ocs']['0'], $params);
+		$protectedPost+=$params;
+		ob_start();
+		$ajax = true;
+	}
+	else{
+		$ajax=false;
+	}
 	print_item_header($l->g(512));
 	$form_name="affich_packets";
 	$table_name=$form_name;
+	$tab_options=$protectedPost;
+	$tab_options['form_name']=$form_name;
+	$tab_options['table_name']=$table_name;
 	echo open_form($form_name);
 	$list_fields=array($l->g(475) => 'PKG_ID',
 					   $l->g(49) => 'NAME',
@@ -30,12 +41,12 @@
 					   'COMMENT'=>'COMMENT');
 	$list_col_cant_del=array($l->g(475)=>$l->g(475),$l->g(49)=>$l->g(49));
 	$default_fields= $list_col_cant_del;
-	$pack_sup="<b><font color=red>".$l->g(561)."</font></b>";
+	$pack_sup= $l->g(561);
 	$queryDetails  = "SELECT PKG_ID,NAME,PRIORITY,FRAGMENTS,round(SIZE/1024,2) as SIZE,OSNAME,COMMENT
 						FROM download_history h LEFT JOIN download_available a ON h.pkg_id=a.fileid 
 						where hardware_id=%s and name is not null";
 	$arg=array($systemid);
-	if (isset($_SESSION['OCS']['RESTRICTION']['TELEDIFF_VISIBLE']) and $_SESSION['OCS']['RESTRICTION']['TELEDIFF_VISIBLE'] == "YES"){
+	if ($_SESSION['OCS']['profile']->getRestriction('TELEDIFF_VISIBLE', 'YES') == "YES"){
 			$queryDetails  .= " and a.comment not like '%s'";
 			array_push($arg,'%[VISIBLE=0]%');
 	}
@@ -48,6 +59,12 @@
 	}
 	array_push($arg,$systemid);
 	$tab_options['ARG_SQL']=$arg;
-	tab_req($table_name,$list_fields,$default_fields,$list_col_cant_del,$queryDetails,$form_name,80,$tab_options);
+	ajaxtab_entete_fixe($list_fields,$default_fields,$tab_options,$list_col_cant_del);
+	
 	echo close_form();
+	if ($ajax){
+		ob_end_clean();
+		tab_req($list_fields,$default_fields,$list_col_cant_del,$queryDetails,$tab_options);
+		ob_start();
+	}
 ?>
\ No newline at end of file
