@@ -10,8 +10,20 @@
 //====================================================================================
 
 function affich_detail_simple($form_name,$list_fields,$list_col_cant_del,$default_fields,$table,$tab_options=array()){
+	if(AJAX){
+		parse_str($protectedPost['ocs']['0'], $params);
+		$protectedPost+=$params;
+		ob_start();
+		$ajax = true;
+	}
+	else{
+		$ajax=false;
+	}
 	$form_name="affich_controllers";
 	$table_name=$form_name;
+	$tab_options=$protectedPost;
+	$tab_options['form_name']=$form_name;
+	$tab_options['table_name']=$table_name;
 	echo open_form($form_name);
 //	$list_fields=array($l->g(64) => 'MANUFACTURER',
 //					   $l->g(49) => 'NAME',
@@ -27,9 +39,12 @@ function affich_detail_simple($form_name,$list_fields,$list_col_cant_del,$defaul
 			$queryDetails .= $value.",";		
 	}
 	$queryDetails  = substr($queryDetails,0,-1)." FROM ".$table." WHERE (hardware_id=$systemid)";
-	tab_req($table_name,$list_fields,$default_fields,$list_col_cant_del,$queryDetails,$form_name,80,$tab_options);
+	ajaxtab_entete_fixe($list_fields,$default_fields,$tab_options,$list_col_cant_del);
 	echo close_form();
-
-
+	if ($ajax){
+		ob_end_clean();
+		tab_req($list_fields,$default_fields,$list_col_cant_del,$queryDetails,$tab_options);
+		ob_start();
+	}
 }
 ?>
\ No newline at end of file
