@@ -9,14 +9,27 @@
 // Please refer to the General Public Licence http://www.gnu.org/ or Licence.txt
 //====================================================================================
 
+if(AJAX){  
+	parse_str($protectedPost['ocs']['0'], $params);
+	$protectedPost+=$params; 
+	ob_start();
+	$ajax = true;
+}
+else{
+	$ajax=false;
+}
 require_once('require/function_computers.php');
 require_once('require/function_admininfo.php');
+//intégration des fonctions liées à la recherche multicritère
+require_once('require/function_search.php');
+
 //show mac address on the tab
 $show_mac_addr=true;
-
-$form_name="show_all";
-$table_name="list_show_all";
-
+$tab_options=$protectedPost;
+$tab_options['form_name']="show_all";
+$form_name = $tab_options['form_name'];
+$tab_options['table_name']="list_show_all";
+//$tab_options['DRAW']=$draw;
 if (isset($protectedGet['filtre']) and !isset($protectedPost['FILTRE'])){
 	if (substr($protectedGet['filtre'], 0, 9) == "a.fields_"){
 		$values_accountinfo=accountinfo_tab(substr($protectedGet['filtre'], 9));
@@ -42,7 +55,7 @@ if ($protectedPost['DEL_ALL'] != ''){
 //delete one computer
 if ($protectedPost['SUP_PROF'] != ''){	
 	deleteDid($protectedPost['SUP_PROF']);
-	$tab_options['CACHE']='RESET';
+	$tab_options['CACHE']='RESET';	
 }
 
 if (!isset($protectedPost['tri_'.$table_name]) or $protectedPost['tri_'.$table_name] == ""){
@@ -51,7 +64,6 @@ if (!isset($protectedPost['tri_'.$table_name]) or $protectedPost['tri_'.$table_n
 }
 echo open_form($form_name);
 //BEGIN SHOW ACCOUNTINFO
-
 $accountinfo_value=interprete_accountinfo($list_fields,$tab_options);
 if (array($accountinfo_value['TAB_OPTIONS']))
 	$tab_options=$accountinfo_value['TAB_OPTIONS'];
@@ -72,7 +84,7 @@ $list_fields2 = array ( $l->g(46) => "h.lastdate",
 					   $l->g(350) => "h.processort",
 					   $l->g(351) => "h.processorn",
 					   $l->g(50) => "h.swap",
-					   $l->g(352) => "lastcome",
+					   $l->g(352) => "h.lastcome",
 					   $l->g(353) => "h.quality",
 					   $l->g(354) => "h.fidelity",
 					   $l->g(53) => "h.description",
@@ -94,17 +106,16 @@ if ($show_mac_addr){
 	$list_fields2[$l->g(207)]="n.ipgateway";
 	$list_fields2[$l->g(331)]="n.ipsubnet";
 }
-					   
+
 $list_fields=array_merge ($list_fields,$list_fields2);
 //asort($list_fields); 
 $tab_options['FILTRE']=array_flip($list_fields);
 $tab_options['FILTRE']['h.name']=$l->g(23);
 asort($tab_options['FILTRE']); 
-if ($_SESSION['OCS']['CONFIGURATION']['DELETE_COMPUTERS'] == "YES"){
-	$list_fields['CHECK']='h.ID';
+if ($_SESSION['OCS']['profile']->getConfigValue('DELETE_COMPUTERS') == "YES"){
+		$list_fields['CHECK']='h.ID';
 		$list_fields['SUP']='h.ID';
 }
-	
 $list_col_cant_del=array('SUP'=>'SUP','NAME'=>'NAME','CHECK'=>'CHECK');
 $default_fields2= array($_SESSION['OCS']['TAG_LBL']['TAG']=>$_SESSION['OCS']['TAG_LBL'],$l->g(46)=>$l->g(46),'NAME'=>'NAME',$l->g(23)=>$l->g(23),
 						$l->g(24)=>$l->g(24),$l->g(25)=>$l->g(25),$l->g(568)=>$l->g(568),
@@ -114,6 +125,7 @@ $sql=prepare_sql_tab($list_fields,array('SUP','CHECK'));
 $tab_options['ARG_SQL']=$sql['ARG'];
 $queryDetails  = $sql['SQL']." from hardware h 
 				LEFT JOIN accountinfo a ON a.hardware_id=h.id  ";
+
 if ($show_mac_addr){
 	$queryDetails  .= "	LEFT JOIN networks n ON n.hardware_id=h.id ";
 	$queryDetails  .= " AND h.IPADDR=n.IPADDRESS ";
@@ -121,6 +133,10 @@ if ($show_mac_addr){
 $queryDetails  .= "LEFT JOIN bios e ON e.hardware_id=h.id 
 				where deviceid<>'_SYSTEMGROUP_' 
 						AND deviceid<>'_DOWNLOADGROUP_' ";
+if (isset($_GET['value']) and $_GET['filtre'] == "a.TAG"){
+	$tag = $_GET['value'];
+	$queryDetails  .= "AND a.TAG= '$tag' ";
+}
 	
 if (isset($_SESSION['OCS']["mesmachines"]) and $_SESSION['OCS']["mesmachines"] != '')
 	$queryDetails  .= "AND ".$_SESSION['OCS']["mesmachines"];
@@ -128,10 +144,43 @@ $queryDetails  .=" group by h.id";
 $tab_options['LBL_POPUP']['SUP']='name';
 $tab_options['LBL']['SUP']=$l->g(122);
 $tab_options['TRI']['DATE']['e.bdate']="%m/%d/%Y";
-$result_exist=tab_req($table_name,$list_fields,$default_fields,$list_col_cant_del,$queryDetails,$form_name,95,$tab_options);
-if ($result_exist != "" and $_SESSION['OCS']['CONFIGURATION']['DELETE_COMPUTERS'] == "YES"){
-		echo "<a href=# OnClick='confirme(\"\",\"DEL_SEL\",\"".$form_name."\",\"DEL_ALL\",\"".$l->g(900)."\");'><img src='image/sup_search.png' title='Supprimer' ></a>";
+
+$entete = ajaxtab_entete_fixe($list_fields,$default_fields,$tab_options,$list_col_cant_del);
+
+// Mass_action boutons 
+// Groups / Delete / Lock result / mass processing / Config / deploy
+if ($_SESSION['OCS']['profile']->getConfigValue('DELETE_COMPUTERS') == "YES"){
+	$list_fonct["image/delete.png"]=$l->g(122);
+	$list_pag["image/delete.png"]=$pages_refs["ms_custom_sup"];
+	$tab_options['LBL_POPUP']['SUP']='name_of_machine';
+}
+$list_fonct["image/cadena_ferme.png"]=$l->g(1019);
+$list_fonct["image/mass_affect.png"]=$l->g(430);
+if ($_SESSION['OCS']['profile']->getConfigValue('CONFIG') == "YES"){
+	$list_fonct["image/config_search.png"]=$l->g(107);
+	$list_pag["image/config_search.png"]=$pages_refs['ms_custom_param'];
+}
+if ($_SESSION['OCS']['profile']->getConfigValue('TELEDIFF') == "YES"){
+	$list_fonct["image/tele_search.png"]=$l->g(428);
+	$list_pag["image/tele_search.png"]=$pages_refs["ms_custom_pack"];
+}
+$list_pag["image/groups_search.png"]=$pages_refs["ms_custom_groups"];
+
+$list_pag["image/cadena_ferme.png"]=$pages_refs["ms_custom_lock"];
+$list_pag["image/mass_affect.png"]=$pages_refs["ms_custom_tag"];
+add_trait_select($list_fonct,$list_id,$form_name,$list_pag,true);
+echo "<br><br>";
+
+if ($entete and $_SESSION['OCS']['profile']->getConfigValue('DELETE_COMPUTERS') == "YES"){
+		//echo "<a href=# OnClick='confirme(\"\",\"DEL_SEL\",\"".$form_name."\",\"DEL_ALL\",\"".$l->g(900)."\");'><img src='image/delete.png' title='Supprimer' ></a>";
+		echo "<a href=# OnClick='confirme(\"\",\"DEL_SEL\",\"".$form_name."\",\"DEL_ALL\",\"".$l->g(900)."\");'><span class='glyphicon glyphicon-trash'></span></a>";
 		echo "<input type='hidden' id='DEL_ALL' name='DEL_ALL' value=''>";
-	}
+}
+	
 echo close_form();
+
+if ($ajax){
+	ob_end_clean();
+	tab_req($list_fields,$default_fields,$list_col_cant_del,$queryDetails,$tab_options);
+}
 ?>
\ No newline at end of file
