@@ -34,6 +34,7 @@ $def_onglets['GUI']=$l->g(84); //GUI
 $def_onglets['CNX']=$l->g(1108); //connexion
 $def_onglets['SNMP']=$l->g(1136); //SNMP
 $def_onglets['WOL']=$l->g(1279); //WOL
+$def_onglets['PLUGINSCONF']=$l->g(6000); //Plugins Configuration
 
 if (DEV_OPTION)
 	$def_onglets['DEV']=$l->g(1302);
@@ -114,6 +115,9 @@ switch ($protectedPost['onglet']){
 	case 'DEV':
 		pagesdev($form_name);
 		break;
+	case 'PLUGINSCONF':
+		pagesplugin($form_name);
+		break;
 	case 'WOL':
 		pageswol($form_name);
 	break;
