@@ -9,6 +9,17 @@
 // Please refer to the General Public Licence http://www.gnu.org/ or Licence.txt
 //====================================================================================
 
+if(AJAX){  
+	parse_str($protectedPost['ocs']['0'], $params);	
+	$protectedPost+=$params; 
+	ob_start();
+	$ajax = true;
+}
+else{
+	$ajax=false;
+}
+
+
 require_once('require/function_config_generale.php');
 $form_name = "console";
 if ($protectedPost['RESET'] == 'FIRST'){
@@ -43,10 +54,11 @@ if (isset($protectedPost["onglet"]) and !isset($data_tab['DATA'][$protectedPost[
 	$protectedPost["onglet"]=$data_tab['DEFAULT'];
 	
 if ($data_tab['DATA'] != array()){
-	onglet($data_tab['DATA'],$form_name,"onglet",8);
-	echo '<div class="mlt_bordure" >';
+	show_tabs($data_tab['DATA'],$form_name,"onglet",8);
 	
-	if ($_SESSION['OCS']['CONFIGURATION']['CONSOLE'] == 'YES'){
+	echo '<div class="right-content"><div class="mlt_bordure" >';
+	
+	if ($_SESSION['OCS']['profile']->getConfigValue('CONSOLE') == 'YES'){
 		echo "<table align='right' border='0'><tr><td colspan=10 align='right'><a href=# OnClick='pag(\"ADMIN\",\"ADMIN\",\"".$form_name."\");'>";
 		if (isset($_SESSION['OCS']['ADMIN_CONSOLE']) and $_SESSION['OCS']['ADMIN_CONSOLE'] == 'ADMIN')
 			echo "<img src='image/success.png'>";
@@ -61,7 +73,7 @@ if ($data_tab['DATA'] != array()){
 		$array_group="";
 		$sql_group="select id,name from hardware where deviceid='_SYSTEMGROUP_'";
 		$res=mysql2_query_secure($sql_group,$_SESSION['OCS']["readServer"]);
-		while ($value = mysql_fetch_object($res)){
+		while ($value = mysqli_fetch_object($res)){
 			$array_group[$value->id]=$value->name;			
 		}
 		if (is_array($array_group)){
@@ -70,11 +82,11 @@ if ($data_tab['DATA'] != array()){
 				delete($protectedPost['SUP_PROF']);	
 			}
 			
-			if (isset($protectedPost["Valid_modif_x"]) and $protectedPost["Valid_modif_x"] != ''){
+			if (isset($protectedPost["Valid_modif"]) and $protectedPost["Valid_modif"] != '') {
 				$sql_msg="select name from config where name like '%s'";
 				$arg="GUI_REPORT_MSG%";
 				$result_msg = mysql2_query_secure($sql_msg,$_SESSION['OCS']["readServer"],$arg);
-				while($item_msg = mysql_fetch_object($result_msg)){
+				while($item_msg = mysqli_fetch_object($result_msg)){
 					$list_name_msg[]=substr($item_msg ->name,14);		
 				}
 				if (isset($list_name_msg)){
@@ -83,19 +95,27 @@ if ($data_tab['DATA'] != array()){
 						if ($v == $i)
 						$i++;			
 					}
-				}else
-				$i=1;
+				} else {
+					$i=1;
+				}
+				
+				$tab_options=$protectedPost;
+				
 				if (trim($protectedPost['GROUP']) != "" and is_numeric($protectedPost['GROUP']) and trim($protectedPost['MESSAGE'])!=""){
 					$sql="insert into config (NAME,IVALUE,TVALUE) values ('%s',%s,'%s')";
 					$arg=array("GUI_REPORT_MSG".$i,$protectedPost['GROUP'],$protectedPost['MESSAGE']);
 					mysql2_query_secure( $sql, $_SESSION['OCS']["writeServer"],$arg );
 					$tab_options['CACHE']='RESET';
-				}else
+				} else {
 					msg_error($l->g(239));
-						
-					}
+				}
+			}else{
+				$tab_options=$protectedPost;
+			}
 		
 			$table_name=$protectedPost['onglet'];
+			$tab_options['table_name']=$table_name;
+			$tab_options['form_name']=$form_name;	
 			$list_fields=array('GROUP_NAME'=>'h.NAME', 
 							   $l->g(915) => 'tvalue',
 							   'SUP'=>'CNAME');
@@ -109,7 +129,7 @@ if ($data_tab['DATA'] != array()){
 			$tab_options['ARG_SQL']=$sql['ARG'];
 			$tab_options['LBL_POPUP']['SUP']=$l->g(919);
 			$tab_options['LBL']['GROUP_NAME']=$l->g(49);
-			tab_req($table_name,$list_fields,$default_fields,$list_col_cant_del,$sql['SQL'],$form_name,80,$tab_options);		
+			ajaxtab_entete_fixe($list_fields,$default_fields,$tab_options,$list_col_cant_del);	
 			echo "<input type='submit' name='NEW' id='NEW' value='".$l->g(617)."' align=center>";
 			if ($protectedPost["NEW"]){
 					$name_field=array("GROUP","MESSAGE");
@@ -130,7 +150,7 @@ if ($data_tab['DATA'] != array()){
 
 	}
 	
-	echo "</div>";
+	echo "</div></div>";
 	echo "<input type=hidden name='ADMIN' value='' id='ADMIN'>";
 	echo "<input type=hidden name='VISIBLE' value='' id='VISIBLE'>";
 	echo "<input type=hidden name='NO_VISIBLE' value='' id='NO_VISIBLE'>";
@@ -159,7 +179,9 @@ if ((isset($protectedPost["SHOW_ME"]) and $protectedPost["SHOW_ME"] != "")){
 	$array_fields=array_values($table_field[$protectedPost["SHOW_ME"]]);
 	echo "<input type=hidden name='SHOW_ME_SAUV' value='".$protectedPost["SHOW_ME"]."' id='SHOW_ME_SAUV'>";
 	$table_name=$protectedPost["SHOW_ME"];
-	
+	$tab_options=$protectedPost;
+	$tab_options['form_name']=$form_name;
+	$tab_options['table_name']=$table_name;	
 	if (!isset($sql_field[$protectedPost["SHOW_ME"]]['SQL']))
 		$sql_field[$protectedPost["SHOW_ME"]]['SQL']="select %s from %s %s";
 	
@@ -196,12 +218,11 @@ if ((isset($protectedPost["SHOW_ME"]) and $protectedPost["SHOW_ME"] != "")){
 		$tab_options['LIEN_LBL'][$l->g(1120)].=$multi_search[$protectedPost["SHOW_ME"]]['FIELD']."&comp=".$multi_search[$protectedPost["SHOW_ME"]]['COMP']."&values=";
 		$tab_options['LIEN_CHAMP'][$l->g(1120)]=$array_fields[0];		
 	}
-	tab_req($table_name,$list_fields,$default_fields,$list_col_cant_del,$sql_field[$protectedPost["SHOW_ME"]]['SQL'],$form_name,50,$tab_options);
-	
+	ajaxtab_entete_fixe($list_fields,$default_fields,$tab_options,$list_col_cant_del);
 }
 echo close_form();
 //show messages
-if ($_SESSION['OCS']['RESTRICTION']['GUI'] == "YES"){
+if ($_SESSION['OCS']['profile']->getRestriction('GUI') == "YES"){
 	$info_msg=look_config_default_values('GUI_REPORT_MSG%','LIKE');
 	if (is_array($info_msg['ivalue']))
 		$list_id_groups=implode(',',$info_msg['ivalue']);
@@ -213,8 +234,8 @@ if ($_SESSION['OCS']['RESTRICTION']['GUI'] == "YES"){
 						and	g_c.GROUP_ID in (".$list_id_groups.")";
 		if (isset($_SESSION['OCS']['mesmachines']) and $_SESSION['OCS']['mesmachines'] != "")
 			$sql_my_msg.= " and ".$_SESSION['OCS']['mesmachines'];
-		$result_my_msg = mysql_query( $sql_my_msg, $_SESSION['OCS']["readServer"]);
-		while($item_my_msg = mysql_fetch_object($result_my_msg)){
+		$result_my_msg = mysqli_query( $_SESSION['OCS']["readServer"],$sql_my_msg);
+		while($item_my_msg = mysqli_fetch_object($result_my_msg)){
 			foreach ($info_msg['ivalue'] as $key=>$value){
 				if ($value == $item_my_msg ->groups){
 					$msg_group[$key]=$info_msg['tvalue'][$key];
@@ -227,6 +248,19 @@ if ($_SESSION['OCS']['RESTRICTION']['GUI'] == "YES"){
 		}
 	}
 }
+
+
+if ($ajax){
+	ob_end_clean();
+	
+	if (isset($sql_field[$protectedPost["SHOW_ME"]]['SQL'])){
+		tab_req($list_fields,$default_fields,$list_col_cant_del,$sql_field[$protectedPost["SHOW_ME"]]['SQL'],$tab_options);
+	}
+	else{
+		tab_req($list_fields,$default_fields,$list_col_cant_del,$sql['SQL'],$tab_options);
+	}
+	
+}
 ?>
 
 
