@@ -8,7 +8,16 @@
 // code is always made freely available.
 // Please refer to the General Public Licence http://www.gnu.org/ or Licence.txt
 //====================================================================================
-
+if(AJAX){  
+		parse_str($protectedPost['ocs']['0'], $params);	
+		$protectedPost+=$params; 
+		
+	ob_start();
+	$ajax = true;
+}
+else{
+	$ajax=false;
+}
 require_once('require/function_computers.php');
 if ($protectedPost['DEL_ALL'] != ''){
 	foreach ($protectedPost as $key=>$value){
@@ -35,8 +44,8 @@ if ($protectedPost['FUSION']){
 		$afus=array();
 		$i=0;
 		while (isset($list_id_fusion[$i])){
-			$res = mysql_query("SELECT deviceid,id,lastcome FROM hardware WHERE id=".$list_id_fusion[$i], $_SESSION['OCS']["readServer"]) or die(mysql_error($_SESSION['OCS']["readServer"]));		
-			$afus[] = mysql_fetch_array($res,MYSQL_ASSOC);	
+			$res = mysqli_query($_SESSION['OCS']["readServer"],"SELECT deviceid,id,lastcome FROM hardware WHERE id=".$list_id_fusion[$i]) or die(mysqli_error($_SESSION['OCS']["readServer"]));		
+			$afus[] = mysqli_fetch_array($res,MYSQL_ASSOC);	
 			$i++;
 		}	
 		if (isset($afus))
@@ -95,7 +104,7 @@ if (isset($tab_id_mes_machines) and $tab_id_mes_machines != ""){
 $sql_doublon['macaddress'].=" group by MACADDR having count(MACADDR)>1";
 foreach($sql_doublon as $name=>$sql_value){
 	$res = mysql2_query_secure($sql_value, $_SESSION['OCS']["readServer"],$arg_doublon[$name]);
-	while( $val = mysql_fetch_object( $res ) ){		
+	while( $val = mysqli_fetch_object( $res ) ){		
 		$doublon[$name][] = $val->val;
 	}
 }
@@ -183,7 +192,7 @@ foreach($sql_id_doublon as $name=>$sql_value){
 	$sql_value.=" group by id";
 	$res = mysql2_query_secure($sql_value, $_SESSION['OCS']["readServer"],$arg_id_doublon[$name]);
 	$count_id[$name] = 0;
-	while( $val = mysql_fetch_object( $res ) ) {
+	while( $val = mysqli_fetch_object( $res ) ) {
 		//if restriction => count only computers of profil
 		//else, all computers
 			if (is_array($tab_id_mes_machines) and in_array ($val->id,$tab_id_mes_machines)){
@@ -198,8 +207,11 @@ foreach($sql_id_doublon as $name=>$sql_value){
 }
 $form_name='doublon';
 $table_name='DOUBLON';
+$tab_options=$protectedPost;
+$tab_options['form_name']=$form_name;
+$tab_options['table_name']=$table_name;
 echo open_form($form_name);
-echo "<br><table BORDER='0' WIDTH = '25%' ALIGN = 'Center' CELLPADDING='0' BGCOLOR='#C7D9F5' BORDERCOLOR='#9894B5'>";
+echo "<table BORDER='0' WIDTH = '25%' ALIGN = 'Center' CELLPADDING='0' BGCOLOR='#C7D9F5' BORDERCOLOR='#9894B5'>";
 foreach ($count_id as $lbl=>$count_value){
 	echo "<tr><td align='center'>";
 	switch($lbl) {
@@ -220,7 +232,7 @@ foreach ($count_id as $lbl=>$count_value){
 	if ($protectedPost['detail'] == $lbl and $count_value == 0)
 	unset($protectedPost['detail']);
 }
-echo "</table><br>";
+echo "</table>";
 echo "<input type=hidden name=detail id=detail value='".$protectedPost['detail']."'>";
 
 //show details
@@ -261,7 +273,7 @@ if ($protectedPost['detail'] != ''){
 						   $l->g(23).": ".$l->g(46)=>$l->g(23).": ".$l->g(46),
 						   $l->g(23).": ".$l->g(34)=>$l->g(23).": ".$l->g(34));
 	$default_fields=array_merge ($default_fields,$default_fields2);
-	if ($_SESSION['OCS']['CONFIGURATION']['DELETE_COMPUTERS'] == "YES"){
+	if ($_SESSION['OCS']['profile']->getConfigValue('DELETE_COMPUTERS') == "YES"){
 		$list_fields['SUP']='h.ID';
 		$list_col_cant_del['SUP']='SUP';
 	}
@@ -283,15 +295,18 @@ if ($protectedPost['detail'] != ''){
 	$tab_options['FILTRE']=array('NAME'=>$l->g(35),'b.ssn'=>$l->g(36),'n.macaddr'=>$l->g(95));
 	$tab_options['LBL_POPUP']['SUP']='NAME';
 	$tab_options['LBL']['SUP']=$l->g(122);
-	$result_exist=tab_req($table_name,$list_fields,$default_fields,$list_col_cant_del,$sql['SQL'],$form_name,'95',$tab_options);
-	if ($result_exist != "" and $_SESSION['OCS']['CONFIGURATION']['DELETE_COMPUTERS'] == "YES"){
-		echo "<a href=# OnClick='confirme(\"\",\"DEL_SEL\",\"".$form_name."\",\"DEL_ALL\",\"".$l->g(900)."\");'><img src='image/sup_search.png' title='Supprimer' ></a>";
+	$result_exist=ajaxtab_entete_fixe($list_fields,$default_fields,$tab_options,$list_col_cant_del);
+	if ($result_exist != "" and $_SESSION['OCS']['profile']->getConfigValue('DELETE_COMPUTERS') == "YES"){
+		echo "<a href=# OnClick='confirme(\"\",\"DEL_SEL\",\"".$form_name."\",\"DEL_ALL\",\"".$l->g(900)."\");'><img src='image/delete.png' title='Supprimer' ></a>";
 		echo "<input type='hidden' id='DEL_ALL' name='DEL_ALL' value=''>";
 	}
-	echo "<br><input type='submit' value='".$l->g(177)."' name='FUSION'>";
+	echo "<p><input type='submit' value='".$l->g(177)."' name='FUSION'></p>";
 	echo "<input type=hidden name=old_detail id=old_detail value='".$protectedPost['detail']."'>";
 }
 echo close_form();
 
-
+if ($ajax){
+	ob_end_clean();
+	tab_req($list_fields,$default_fields,$list_col_cant_del,$sql['SQL'],$tab_options);
+}
 ?>
