@@ -82,8 +82,8 @@ elseif (isset($_SESSION['OCS']['csv']['SQL'][$protectedGet['tablename']])){
 		$i=0;
 		
 		while($_SESSION['OCS']['SQL_DATA_FIXE'][$protectedGet['tablename']][$i]){
-			$result=mysql_query($_SESSION['OCS']['SQL_DATA_FIXE'][$protectedGet['tablename']][$i], $link) or die(mysql_error($link));
-			while( $cont = mysql_fetch_array($result,MYSQL_ASSOC) ) {
+			$result=mysqli_query($link,$_SESSION['OCS']['SQL_DATA_FIXE'][$protectedGet['tablename']][$i]) or die(mysqli_error($link));
+			while( $cont = mysqli_fetch_array($result,MYSQL_ASSOC) ) {
 				foreach ($col as $field => $lbl){
 					if (array_key_exists($lbl,$cont)){
 					
@@ -96,17 +96,23 @@ elseif (isset($_SESSION['OCS']['csv']['SQL'][$protectedGet['tablename']])){
 		
 	}
 
-
+	//var_dump($data_fixe);
 	if ($_SESSION['OCS']['csv']['ARG'][$protectedGet['tablename']])
 		$arg=$_SESSION['OCS']['csv']['ARG'][$protectedGet['tablename']];
 	else
 		$arg='';	
-	$result=mysql2_query_secure($_SESSION['OCS']['csv']['SQL'][$protectedGet['tablename']], $link,$arg);
+	
+	if(isset($protectedGet['nolimit'])){
+		$result=mysql2_query_secure($_SESSION['OCS']['csv']['SQLNOLIMIT'][$protectedGet['tablename']], $link,$arg);
+	}
+	else{
+		$result=mysql2_query_secure($_SESSION['OCS']['csv']['SQL'][$protectedGet['tablename']], $link,$arg);
+	}
 	$i=0;
 	require_once('require/function_admininfo.php');
 	$inter=interprete_accountinfo($col,array());
-	while( $cont = mysql_fetch_array($result,MYSQL_ASSOC) ) {
-						//p($cont);
+	while( $cont = mysqli_fetch_array($result,MYSQL_ASSOC) ) {
+		unset($cont['MODIF']);
 		foreach ($col as $field => $lbl){
 			if ($lbl == "name_of_machine" and !isset($cont[$field])){
 				$field='name';
@@ -114,6 +120,7 @@ elseif (isset($_SESSION['OCS']['csv']['SQL'][$protectedGet['tablename']])){
 			
 			$found = false;
 			// find value case-insensitive
+	
 			foreach ($cont as $key => $val) {
 				if (strtolower($key) == strtolower($field)) {
 					if (($field == 'TAG' or substr($field,0,7) == 'fields_')
@@ -128,16 +135,32 @@ elseif (isset($_SESSION['OCS']['csv']['SQL'][$protectedGet['tablename']])){
 					$found = true;
 					break;
 				}
-			}
-			
-			if (!$found) {
-				// find values case-insensitive
-				foreach ($data_fixe[$cont['ID']] as $key => $val) {
-					if (strtolower($key) == strtolower($field) && isset($data_fixe[$cont['ID']][$key])) {
-						$data[$i][$lbl]=$data_fixe[$cont['ID']][$key];
-						
+				elseif(isset($_SESSION['OCS']['VALUE_FIXED'][$protectedGet['tablename']][$lbl][$cont['ID']]) && isset($cont['ID'])){
+					$data[$i][$lbl] = $_SESSION['OCS']['VALUE_FIXED'][$protectedGet['tablename']][$lbl][$cont['ID']];
 						$found = true;
 						break;
+				}
+				
+			
+				
+			}
+			if(isset($_SESSION['OCS']['csv']['REPLACE_VALUE'][$protectedGet['tablename']][$key])){
+				$data[$i][$key]=$_SESSION['OCS']['csv']['REPLACE_VALUE'][$protectedGet['tablename']][$key][$data[$i][$key]];
+			}
+			if(isset($_SESSION['OCS']['csv']['REPLACE_VALUE_ALL_TIME'][$protectedGet['tablename']][$key])){
+				$data[$i][$key] = $_SESSION['OCS']['csv']['REPLACE_VALUE_ALL_TIME'][$protectedGet['tablename']][$data[$i][$_SESSION['OCS']['csv']['FIELD_REPLACE_VALUE_ALL_TIME'][$protectedGet['tablename']]]];
+			}
+			if (!$found) {
+				// find values case-insensitive
+				
+				if(!is_null($data_fixe[$cont['ID']])){
+					foreach ($data_fixe[$cont['ID']] as $key => $val) {
+						if (strtolower($key) == strtolower($field) && isset($data_fixe[$cont['ID']][$key])) {
+							$data[$i][$lbl]=$data_fixe[$cont['ID']][$key];
+					
+							$found = true;
+							break;
+						}
 					}
 				}
 				
@@ -161,7 +184,6 @@ elseif (isset($_SESSION['OCS']['csv']['SQL'][$protectedGet['tablename']])){
 
 	$filename="export.csv";
 }
-	
 if ($toBeWritten != ""){
 	// iexplorer problem
 	if( ini_get("zlib.output-compression"))
