@@ -8,19 +8,32 @@
 // code is always made freely available.
 // Please refer to the General Public Licence http://www.gnu.org/ or Licence.txt
 //====================================================================================
+if(AJAX){  
+		parse_str($protectedPost['ocs']['0'], $params);	
+		$protectedPost+=$params; 
+		
+	ob_start();
+	$ajax = true;
+}
+else{
+	$ajax=false;
+}
+
+
 
 require_once('require/function_ipdiscover.php');
-
+require_once("require/function_graphic.php");
 if (!isset($_SESSION['OCS']["mac"]))
 	loadMac();
 	
 printEntete($l->g(312));
-echo "<br>";	
 
  $form_name='ipdiscover';
+ $tab_options=$protectedPost;
+ $tab_options['form_name']=$form_name;
 echo open_form($form_name);
  	//delete a subnet
- 	if (isset($protectedPost['SUP_PROF']) and $protectedPost['SUP_PROF'] != '' and $_SESSION['OCS']['CONFIGURATION']['IPDISCOVER'] == "YES"){
+ 	if (isset($protectedPost['SUP_PROF']) and $protectedPost['SUP_PROF'] != '' and $_SESSION['OCS']['profile']->getConfigValue('IPDISCOVER') == "YES"){
  		$sql_del="delete from subnet where netid='%s'";
  		$arg_del=$protectedPost['SUP_PROF'];
  		mysql2_query_secure($sql_del, $_SESSION['OCS']["writeServer"],$arg_del);
@@ -76,7 +89,6 @@ echo open_form($form_name);
 					LEFT JOIN networks ns ON ns.macaddr=n.mac
 					WHERE n.mac NOT IN (SELECT DISTINCT(macaddr) FROM network_devices) 
 						and (ns.macaddr IS NULL OR ns.IPSUBNET <> n.netid) 
-	 					and ns.HARDWARE_ID IS NULL
 						and n.netid in  ";
 	 	$arg=mysql2_prepare($arg['SQL'],$arg['ARG'],$array_rsx);
 	 	$arg['SQL'] .= " GROUP BY netid) 
@@ -89,10 +101,11 @@ echo open_form($form_name);
 							'NON_INVENTORIE'=>'NON_INVENTORIE',
 							'IPDISCOVER'=>'IPDISCOVER',
 							'IDENTIFIE'=>'IDENTIFIE');
-	if ($_SESSION['OCS']['CONFIGURATION']['IPDISCOVER'] == "YES")
+	if ($_SESSION['OCS']['profile']->getConfigValue('IPDISCOVER') == "YES")
 	$list_fields['SUP']='ID';	
 	$list_fields['PERCENT_BAR']='pourcentage';
 	$table_name="IPDISCOVER";
+	$tab_options['table_name']=$table_name;
 	$default_fields= $list_fields;
 	$list_col_cant_del=array('RSX'=>'RSX','SUP'=>'SUP');
 	$tab_options['LIEN_LBL']['INVENTORIE']='index.php?'.PAG_INDEX.'='.$pages_refs['ms_custom_info'].'&head=1&prov=inv&value=';
@@ -134,7 +147,7 @@ echo open_form($form_name);
 	$tab_options['LBL']['PERCENT_BAR']=$l->g(1125);
 
 	//you can modify your subnet if ipdiscover is local define
-	if ( $_SESSION['OCS']["ipdiscover_methode"] == "OCS" and $_SESSION['OCS']['CONFIGURATION']['IPDISCOVER'] == "YES"){
+	if ( $_SESSION['OCS']["ipdiscover_methode"] == "OCS" and $_SESSION['OCS']['profile']->getConfigValue('IPDISCOVER') == "YES"){
 		$tab_options['LIEN_LBL']['LBL_RSX']='index.php?'.PAG_INDEX.'='.$pages_refs['ms_admin_ipdiscover'].'&head=1&value=';
 		$tab_options['LIEN_CHAMP']['LBL_RSX']='ID';
 		$tab_options['LIEN_TYPE']['LBL_RSX']='POPUP';
@@ -146,13 +159,18 @@ echo open_form($form_name);
 	$tab_options['NO_TRI']['LBL_RSX']='LBL_RSX';
 	$val_count=count_noinv_network_devices($dpt[$protectedPost['DPT_CHOISE']]);
 
-	$strEnTete = $_SESSION['OCS']["ipdiscover_id"]." ".$dpt[$protectedPost['DPT_CHOISE']]." <br>";
-		$strEnTete .= "<br>(<font color='red'>".$val_count."</font> ".$l->g(219).")";
-		echo "<br><br>";	
+	$strEnTete = "<p>".$_SESSION['OCS']["ipdiscover_id"]." ".$dpt[$protectedPost['DPT_CHOISE']]." <br>";
+		$strEnTete .= "(<font color='red'>".$val_count."</font> ".$l->g(219).")</p>";
 		printEnTete($strEnTete);
-		echo "<br><br>";
-	$result_exist=tab_req($table_name,$list_fields,$default_fields,$list_col_cant_del,$arg['SQL'] ,$form_name,80,$tab_options); 
-
-}
+	$result_exist=ajaxtab_entete_fixe($list_fields,$default_fields,$tab_options,$list_col_cant_del);
+	}
 echo close_form();
+
+
+if ($ajax){
+	ob_end_clean();
+	tab_req($list_fields,$default_fields,$list_col_cant_del,$arg['SQL'],$tab_options);
+}
+
+
 ?>
