@@ -18,35 +18,36 @@ echo "<div align=center>";
 $list_id=multi_lot($form_name,$l->g(601));
 if (isset($list_id) and $list_id != ''){
 	//cas of TAG INFO
-	if (isset($protectedPost['Valid_modif_x']) and $protectedPost['Valid_modif_x'] != ''){
+	if (isset($protectedPost['Valid_modif']) and $protectedPost['Valid_modif'] != ''){
 		$info_account_id=admininfo_computer();
 	
 		foreach ($protectedPost as $field=>$value){
-				
-				if (substr($field, 0, 5) == "check"){
-					$temp=substr($field, 5);
-					if (array_key_exists($temp,$info_account_id)){
-						//cas of checkbox
-						foreach ($protectedPost as $field2=>$value2){
-							$casofcheck=explode('_',$field2);
-							if ($casofcheck[0] . '_' . $casofcheck[1] == $temp){
-								if (isset($casofcheck[2]))
-									$data_fields_account[$temp] .= $casofcheck[2] . "&&&";
-								
-							}						
-						}
-						if (!isset($data_fields_account[$temp]))
-						$data_fields_account[$temp]=$protectedPost[$temp];	
-			
-					}			
-				
-				}
-			}
 	
-		if (isset($data_fields_account)){	
+			if (substr($field, 0, 5) == "check"){
+				$temp=substr($field, 5);
+				if (array_key_exists($temp,$info_account_id)){
+					//cas of checkbox
+					foreach ($protectedPost as $field2=>$value2){
+						$casofcheck=explode('_',$field2);
+						if ($casofcheck[0] . '_' . $casofcheck[1] == $temp){
+							if (isset($casofcheck[2]))
+								$data_fields_account[$temp] .= $casofcheck[2] . "&&&";
+	
+						}
+					}
+					if (!isset($data_fields_account[$temp]))
+						$data_fields_account[$temp]=$protectedPost[$temp];
+							
+				}
+	
+			}
+		}
+	
+		if (isset($data_fields_account)){
 			updateinfo_computer($list_id,$data_fields_account,'LIST');
 			unset($_SESSION['OCS']['DATA_CACHE']['TAB_MULTICRITERE']);
 			echo "<script language='javascript'> window.opener.document.multisearch.submit();</script>";
+			echo "<script language='javascript'> window.opener.document.show_all.submit();</script>";
 		}
 	}
 	
@@ -56,7 +57,7 @@ if (isset($list_id) and $list_id != ''){
 				where fileid='%s'";
 		$arg=$protectedPost['pack_list'];
 		$result = mysql2_query_secure($sql, $_SESSION['OCS']["readServer"],$arg);
-		$item = mysql_fetch_object($result);
+		$item = mysqli_fetch_object($result);
 		require_once('require/function_telediff.php');
 		$nb_line_affected=desactive_packet($list_id,$item->ID);
 		msg_success($nb_line_affected." ".$l->g(1026));	
@@ -70,7 +71,7 @@ if (isset($list_id) and $list_id != ''){
 		$tab_result=mysql2_prepare($sql,$arg,$list_id);
 		$resultDetails = mysql2_query_secure($tab_result['SQL'], $_SESSION['OCS']["writeServer"],$tab_result['ARG']);
 		$msg="";
-		while($item = mysql_fetch_object($resultDetails)){
+		while($item = mysqli_fetch_object($resultDetails)){
 			$wol->wake($item->MACADDR,$item->IPADDRESS);
 			$msg.= "<br>".$wol->wol_send."=>".$item->MACADDR."/".$item->IPADDRESS;			
 		}
@@ -80,13 +81,13 @@ if (isset($list_id) and $list_id != ''){
 	}
 	
 	//tab definition
-	if ($_SESSION['OCS']['CONFIGURATION']['CHANGE_ACCOUNTINFO'] == "YES")
+	if ($_SESSION['OCS']['profile']->getConfigValue('CHANGE_ACCOUNTINFO') == "YES")
 		$def_onglets['TAG']=$l->g(1022); 
 	else
 		$protectedPost['onglet']='SUP_PACK';
 	$def_onglets['SUP_PACK']=$l->g(1021);
 	
-	if (!isset($_SESSION['OCS']['RESTRICTION']['WOL']) or $_SESSION['OCS']['RESTRICTION']['WOL']=="NO")
+	if ($_SESSION['OCS']['profile']->getRestriction('WOL', 'NO')=="NO")
 		$def_onglets['WOL']=$l->g(1280);
 	
 	if ($protectedPost['onglet'] == "")
@@ -110,20 +111,20 @@ if (isset($list_id) and $list_id != ''){
 						if ($field_of_accountinfo['LIST_TYPE'][$id] == 6){
 							$tab_typ_champ[$i]['CONFIG']['MAXLENGTH']=10;
 							$tab_typ_champ[$i]['CONFIG']['SIZE']=10;
-							$tab_typ_champ[$i]['COMMENT_BEHING']=calendars($truename,"DDMMYYYY")."</a></td><td><input type='checkbox' name='check".$truename."' id='check".$truename."' ".(isset($protectedPost['check'.$truename])? " checked ": "").">";
+							$tab_typ_champ[$i]['COMMENT_AFTER']=calendars($truename,"DDMMYYYY")."</a></td><td><input type='checkbox' name='check".$truename."' id='check".$truename."' ".(isset($protectedPost['check'.$truename])? " checked ": "").">";
 						}elseif (in_array($field_of_accountinfo['LIST_TYPE'][$id],array(2,4,7))){
 							$sql="select ivalue as ID,tvalue as NAME from config where name like 'ACCOUNT_VALUE_%s' order by 2";
 							$arg= $field_of_accountinfo['LIST_NAME'][$id]."%";
 							$result=mysql2_query_secure($sql,$_SESSION['OCS']["readServer"],$arg);
-							while ($val = mysql_fetch_array( $result )){
+							while ($val = mysqli_fetch_array( $result )){
 								$tab_typ_champ[$i]['DEFAULT_VALUE'][$val['ID']]=$val['NAME'];
 								
 							}
-							$tab_typ_champ[$i]['COMMENT_BEHING']="</td><td><input type='checkbox' name='check".$truename."' id='check".$truename."' ".(isset($protectedPost['check'.$truename])? " checked ": "").">";
+							$tab_typ_champ[$i]['COMMENT_AFTER']="</td><td><input type='checkbox' name='check".$truename."' id='check".$truename."' ".(isset($protectedPost['check'.$truename])? " checked ": "").">";
 							
 							
 						}else{
-							$tab_typ_champ[$i]['COMMENT_BEHING']="</td><td><input type='checkbox' name='check".$truename."' id='check".$truename."' ".(isset($protectedPost['check'.$truename])? " checked ": "").">";
+							$tab_typ_champ[$i]['COMMENT_AFTER']="</td><td><input type='checkbox' name='check".$truename."' id='check".$truename."' ".(isset($protectedPost['check'.$truename])? " checked ": "").">";
 							$tab_typ_champ[$i]['CONFIG']['MAXLENGTH']=100;
 							$tab_typ_champ[$i]['CONFIG']['SIZE']=30;
 							
@@ -137,7 +138,9 @@ if (isset($list_id) and $list_id != ''){
 							$i++;
 					}
 				}
-				tab_modif_values($tab_name,$tab_typ_champ,array('TAG_MODIF'=>$protectedPost['MODIF'],'FIELD_FORMAT'=>$type_field[$protectedPost['MODIF']]),$l->g(895),"");
+				tab_modif_values($tab_name,$tab_typ_champ,array('TAG_MODIF'=>$protectedPost['MODIF'],'FIELD_FORMAT'=>$type_field[$protectedPost['MODIF']]),array(
+					'title' => $l->g(895)
+				));
 				
 			}elseif ($protectedPost['onglet']=="SUP_PACK"){
 				echo "<div class='mvt_bordure'>";			
@@ -145,7 +148,7 @@ if (isset($list_id) and $list_id != ''){
 									from download_available d_a, download_enable d_e 
 									where d_e.FILEID=d_a.FILEID group by d_a.NAME  order by 1 desc";
 				$resultDetails = mysql2_query_secure($queryDetails, $_SESSION['OCS']["readServer"]);
-				while($val = mysql_fetch_array($resultDetails)){
+				while($val = mysqli_fetch_array($resultDetails)){
 					$List[$val["fileid"]]=$val["name"];		
 				}
 				$select=show_modif($List,'pack_list',2,$form_name);
@@ -158,7 +161,7 @@ if (isset($list_id) and $list_id != ''){
 					$tab_result=mysql2_prepare($sql,$arg,$list_id);
 					$sql= $tab_result['SQL'] . " group by tvalue";
 					$result = mysql2_query_secure($sql, $_SESSION['OCS']["readServer"],$tab_result['ARG'] );
-					while ($item = mysql_fetch_object($result)){
+					while ($item = mysqli_fetch_object($result)){
 						if ($item->tvalue == "")
 							$value=$l->g(482);
 						else
