@@ -8,9 +8,20 @@
 // code is always made freely available.
 // Please refer to the General Public Licence http://www.gnu.org/ or Licence.txt
 //====================================================================================
-
+	if(AJAX){
+		parse_str($protectedPost['ocs']['0'], $params);
+		$protectedPost+=$params;
+		ob_start();
+		$ajax = true;
+	}
+	else{
+		$ajax=false;
+	}
 	$form_name="repart_tag";
 	$table_name=$form_name;
+	$tab_options=$protectedPost;
+	$tab_options['form_name']=$form_name;
+	$tab_options['table_name']=$table_name;
 	echo open_form($form_name);
 	if (!isset($protectedPost['TAG_CHOISE']) or $protectedPost['TAG_CHOISE'] == '')
 		$protectedPost['TAG_CHOISE'] = 'a.TAG';
@@ -24,11 +35,9 @@
 	if (isset($protectedPost['TAG_CHOISE'])){
 		$tag=$protectedPost['TAG_CHOISE'];		
 	}
-
 	if (array($accountinfo_value['TAB_OPTIONS'])){
-		$tab_options['REPLACE_VALUE']['ID']=$accountinfo_value['TAB_OPTIONS']['REPLACE_VALUE'][$list_fields_flip[$tag]];
+		$tab_options['replace_query_arg']['ID']=$tag;
 	}
-
 	unset($list_fields);
 	$list_fields['ID']='ID';
 	$tab_options['LBL']['ID']=$list_fields_flip[$tag];
@@ -44,7 +53,13 @@
 		$queryDetails  .= " AND ".$_SESSION['OCS']["mesmachines"];
 	$tab_options['ARG_SQL'][]=$tag;	
 	$queryDetails  .= "group by ID";
-	tab_req($table_name,$list_fields,$default_fields,$list_col_cant_del,$queryDetails,$form_name,95,$tab_options);
+	ajaxtab_entete_fixe($list_fields,$default_fields,$tab_options,$list_col_cant_del);
 	echo close_form();
-
-?>
\ No newline at end of file
+	
+	
+	if ($ajax){
+		ob_end_clean();
+		tab_req($list_fields,$default_fields,$list_col_cant_del,$queryDetails,$tab_options);
+		
+	}
+	?>
\ No newline at end of file
