@@ -19,7 +19,7 @@
 //show all columns in accountinfo table
 $sql="show columns from accountinfo";
 $res=mysql2_query_secure($sql,$_SESSION['OCS']["readServer"]);
-while ($value = mysql_fetch_object($res)){
+while ($value = mysqli_fetch_object($res)){
 	if ($value->Field != 'HARDWARE_ID' and $value->Field != 'TAG')
 		$list_field[$value->Field]=$value->Field;
 		$type_field[$value->Field]=$value->Type;
@@ -28,7 +28,7 @@ $fields_table=array('ID','NAME_ACCOUNTINFO','TYPE,NAME','ID_TAB','COMMENT','SHOW
 $sql=prepare_sql_tab($fields_table);
 $sql['SQL'] .="from accountinfo_config where ACCOUNT_TYPE='COMPUTERS'";
 $res=mysql2_query_secure($sql['SQL'],$_SESSION['OCS']["readServer"],$sql['ARG']);
-while ($value = mysql_fetch_object($res)){
+while ($value = mysqli_fetch_object($res)){
 	if (!isset($max_order) or $value->SHOW_ORDER > $max_order)
 		$max_order=$value->SHOW_ORDER;
 	if ($value->NAME_ACCOUNTINFO != 'TAG'){
@@ -78,7 +78,7 @@ foreach ($list_field as $name){
 		else
 			$add_lign_accountinfo_config[]=$sql['ARG'];
 		$sql_alter="ALTER TABLE accountinfo CHANGE %s  %s %s";
-		$arg=array($name,"fields_".mysql_insert_id($_SESSION['OCS']["writeServer"]),$type_field[$name]);
+		$arg=array($name,"fields_".mysqli_insert_id($_SESSION['OCS']["writeServer"]),$type_field[$name]);
 		
 		if (isset($protectedPost['EXE']) and $protectedPost['EXE']!= ''){
 			mysql2_query_secure($sql_alter,$_SESSION['OCS']["writeServer"],$arg);			
@@ -89,22 +89,21 @@ foreach ($list_field as $name){
 	
 }
 }
-
+$add_colum_accountinfo=array('1','2');
 if (isset($add_colum_accountinfo) or isset($add_lign_accountinfo_config) or isset($rename_col_accountinfo)){
 		
 		
 		$form_name = "console";
 		echo open_form($form_name);
-		echo "<b>This script is going to help you to update your old admin info<br>";
-		echo "to the new version 2.0 <br><br></b> ";
+		echo "<p><b>This script is going to help you to update your old admin info<br>";
+		echo "to the new version 2.0 </b> </p>";
 		echo "<input type=submit id='EXE' name='EXE'>";
 		echo close_form();
-		echo "<br>";
 		echo '<div class="mlt_bordure" >';
-		echo "<font size=4><i>Summary of actions to be undertaken</i></font><br><br>";
+		echo "<p><font size=4><i>Summary of actions to be undertaken</i></font></p>";
 		if (isset($add_colum_accountinfo)){
-			echo "<b><font color=red>add column in accountinfo table<br>
-					(orphans found in accountinfo_config table (Inconsistency))<br><br></font></b>";
+			echo "<p><b><font color=red>add column in accountinfo table<br>
+					(orphans found in accountinfo_config table (Inconsistency))</font></b></p>";
 			foreach($add_colum_accountinfo as $key=>$values){
 				echo $values."<br>";		
 			}	
@@ -112,10 +111,11 @@ if (isset($add_colum_accountinfo) or isset($add_lign_accountinfo_config) or isse
 		
 		
 		if (isset($add_lign_accountinfo_config)){
-			echo "<b><font color=blue>add lignes in accountinfo_config table<br>
-					(orphans found in accountinfo table (=> 2.0))<br><br></font></b>";
+			echo "<p><b><font color=blue>add lignes in accountinfo_config table<br>
+					(orphans found in accountinfo table (=> 2.0))</font></b></p>";
 			foreach($add_lign_accountinfo_config as $key=>$values){
 				$i=0;
+				echo "<p>";
 				while (isset($values[$i])){
 					echo $values[$i];
 					echo "&nbsp;";
@@ -123,13 +123,12 @@ if (isset($add_colum_accountinfo) or isset($add_lign_accountinfo_config) or isse
 						echo "<br>";
 					$i++;	
 				}
-				echo "<br><br><br>";		
+				echo "</p>";		
 			}	
-			echo "<br>";
 		}
 		if (isset($rename_col_accountinfo)){
-			echo "<b><font color=blue>Renaming of old columns in accountinfo table
-					<br>(=> 2.0)<br><br><br></font></b>";
+			echo "<p><b><font color=blue>Renaming of old columns in accountinfo table
+					<br>(=> 2.0)</font></b></p>";
 			foreach($rename_col_accountinfo as $key=>$values){
 				echo $values[0]."<br>";
 			}	
