@@ -17,8 +17,8 @@ echo open_form($form_name);
 $plugin=false;
 $stats='';
 
-foreach ($_SESSION['OCS']['URL'] as $name=>$lbl){
-	if (substr($name,0,9) == 'ms_stats_' and $_SESSION['OCS']['DIRECTORY'][$name] == 'ms_stats'){
+foreach ($_SESSION['OCS']['url_service']->getUrls() as $name=>$url){
+	if (substr($name,0,9) == 'ms_stats_' and $url['directory'] == 'ms_stats'){
 		$plugin=true;
 		require_once($name.".php");
 	}	
@@ -26,8 +26,8 @@ foreach ($_SESSION['OCS']['URL'] as $name=>$lbl){
 
 if ($plugin){
 	//Create the chart - Column 3D Chart with data from strXML variable using dataXML method
-	onglet($data_on,$form_name,"onglet",4);
-	echo '<div class="mlt_bordure" >';
+	show_tabs($data_on,$form_name,"onglet",4);
+	echo '<div class="right-content mlt_bordure" >';
 	echo $stats;		
 	echo "</div>";
 }else
