@@ -9,6 +9,17 @@
 // Please refer to the General Public Licence http://www.gnu.org/ or Licence.txt
 //====================================================================================
 //Modified on $Date: 2010 $$Author: Erwan Goalou
+if(AJAX){
+	parse_str($protectedPost['ocs']['0'], $params);
+	$protectedPost+=$params;
+	ob_start();
+	$ajax = true;
+}
+else{
+	$ajax=false;
+}
+
+
 require_once('require/function_telediff.php');
 require_once('require/function_computers.php');
 
@@ -18,12 +29,12 @@ $show_stats=true;
 echo open_form($form_name);
 PrintEnTete($l->g(465));
 
-if ($_SESSION['OCS']['RESTRICTION']['TELEDIFF_ACTIVATE'] == 'NO')
+if ($_SESSION['OCS']['profile']->getRestriction('TELEDIFF_ACTIVATE') == 'NO')
 	$cant_active=false;
 else
 	$cant_active=true;
 
-if ($_SESSION['OCS']['RESTRICTION']['GUI'] == 'YES'){
+if ($_SESSION['OCS']['profile']->getRestriction('GUI') == 'YES'){
 	$restrict_computers=computer_list_by_tag('','ARRAY');
 	if ($restrict_computers == "ERROR"){
 		msg_error($l->g(893));
@@ -31,6 +42,9 @@ if ($_SESSION['OCS']['RESTRICTION']['GUI'] == 'YES'){
 		die();
 	}
 }
+$tab_options=$protectedPost;
+
+
 //only for profils who can activate packet
 if (!$cant_active){	
 	if($protectedPost["SUP_PROF"] != "") {
@@ -48,8 +62,9 @@ if (!$cant_active){
 
 if (!$protectedPost['SHOW_SELECT']){
 $protectedPost['SHOW_SELECT']='download';
-
+$tab_options['SHOW_SELECT']='download';
 }
+
 echo "<BR>".show_modif(array('download'=>$l->g(990),'server'=>$l->g(991)),'SHOW_SELECT',2,$form_name)."<BR><BR>";
 
 //only for profils who can activate packet
@@ -63,7 +78,7 @@ if (!$cant_active){
 	$document_root = $info_document_root["tvalue"][$config_document_root];
 	//if no directory in base, take $_SERVER["DOCUMENT_ROOT"]
 	if (!isset($document_root)){
-			$document_root = DOCUMENT_ROOT."download";
+			$document_root = VARLIB_DIR.'/download';
 			if ($protectedPost['SHOW_SELECT'] == "server")
 				$document_root .="server/";
 			
@@ -71,8 +86,10 @@ if (!$cant_active){
 	//can we have the zip?	
 		$document_root .= "/download";
 	}
-	$dir = @opendir($document_root);
-	if ($dir){		
+	
+
+	if (is_readable($document_root) && is_dir($document_root)){		
+		$dir = @opendir($document_root);
 		while($f = readdir($dir)){
 			if (is_numeric ($f))
 			$tab_options['SHOW_ONLY']['ZIP'][$f]=$f;
@@ -80,9 +97,9 @@ if (!$cant_active){
 		if (!$tab_options['SHOW_ONLY']['ZIP'])
 		$tab_options['SHOW_ONLY']['ZIP']='NULL';
 	}else
-	$tab_options['SHOW_ONLY']['ZIP']='NULL';
-}else
-	$tab_options['SHOW_ONLY']['ZIP']='NULL';
+		$tab_options['SHOW_ONLY']['ZIP']='NULL';
+	}else
+		$tab_options['SHOW_ONLY']['ZIP']='NULL';
 
 //only for profils who can activate packet
 if (!$cant_active){		
@@ -118,6 +135,8 @@ $list_fields= array($l->g(475)=>'FILEID',
 							$l->g(462)." KB"=>'round(SIZE/1024,2)',
 							$l->g(25)=>'OSNAME',
 							$l->g(53)=>'COMMENT');
+$tab_options['REPLACE_COLUMN_KEY'][$l->g(593)]='CREADATE'; 
+$tab_options['REPLACE_COLUMN_KEY'][$l->g(462)." KB"]='WEIGHT';
 if ($show_stats){
 	$list_fields['NO_NOTIF']='NO_NOTIF';
 	$list_fields['NOTI']='NOTI';
@@ -162,8 +181,7 @@ else
 	$querypack['SQL'] .= " where comment like '%s'";
 array_push($querypack['ARG'],"[PACK REDISTRIBUTION%");
 $arg_count=array("[PACK REDISTRIBUTION%");
-if (isset($_SESSION['OCS']['RESTRICTION']['TELEDIFF_VISIBLE']) 
-		and $_SESSION['OCS']['RESTRICTION']['TELEDIFF_VISIBLE'] == "YES" ){
+if ($_SESSION['OCS']['profile']->getRestriction('TELEDIFF_VISIBLE', 'YES') == "YES" ){
 		$querypack['SQL'] .= " and comment not like '%s'";
 	array_push($querypack['ARG'],"%[VISIBLE=0]%");	
 	array_push($arg_count,"%[VISIBLE=0]%");	
@@ -243,8 +261,8 @@ if ($show_stats){
 				$_SESSION['OCS']['SQL_DATA_FIXE'][$table_name][$key]=$sql_data_fixe_ter." group by FILEID";	
 		}
 	}
-}
-			
+}	
+		
 $tab_options['COLOR']['ERR_']='RED';	
 $tab_options['COLOR']['SUCC']='GREEN';	
 $tab_options['COLOR']['NOTI']='GREY';	
@@ -252,7 +270,9 @@ $tab_options['COLOR']['NO_NOTIF']='BLACK';
 $tab_options['FILTRE']=array('FILEID'=>'Timestamp','NAME'=>$l->g(49));
 $tab_options['TYPE']['ZIP']=$protectedPost['SHOW_SELECT'];
 $tab_options['FIELD_REPLACE_VALUE_ALL_TIME']='FILEID';
-$result_exist=tab_req($table_name,$list_fields,$default_fields,$list_col_cant_del,$querypack['SQL'],$form_name,95,$tab_options); 
+$tab_options['form_name']=$form_name;
+$tab_options['table_name']=$table_name;
+$result_exist= ajaxtab_entete_fixe($list_fields,$default_fields,$tab_options,$list_col_cant_del);
 //only for profils who can activate packet
 if (!$cant_active){		
 	del_selection($form_name);
@@ -266,6 +286,9 @@ if (!$cant_active){
 echo close_form();
 
 
-
+if ($ajax){
+	ob_end_clean();
+	tab_req($list_fields,$default_fields,$list_col_cant_del,$querypack['SQL'],$tab_options);
+}
 
 ?>
