@@ -11,7 +11,6 @@
 //Modified on $Date: 2010 $$Author: Erwan Goalou
 
 require_once('require/function_telediff.php');
-require_once('require/function_telediff_wk.php');
 foreach ($_POST as $key=>$value){
 	$temp_post[$key]=$value;
 }
@@ -51,30 +50,38 @@ if( isset( $protectedPost["VALID_END"] ) ) {
 						'NEED_DONE_ACTION_TEXT'=>$protectedPost['NEED_DONE_ACTION_TEXT'],
 						'GARDEFOU'=>"rien");
 	create_pack($sql_details,$info_details);
-	if ($protectedPost['REDISTRIB_USE'] == 1){
+	
+if ($protectedPost['REDISTRIB_USE'] == 1){
+		
 		$timestamp_redistrib= time();
 		$server_dir=$protectedPost['download_rep_creat'];
-		$rep=$server_dir.$timestamp_redistrib;
 		//create zip file for redistribution servers
-		require_once("libraries/zip.lib.php");
-		$zipfile = new zipfile();
+		$zipfile = new ZipArchive();
+		$rep = $protectedPost['document_root'].$sql_details['timestamp']."/";
 		
 		if (!file_exists($server_dir)){
 			mkdir($server_dir);
 		}
-		if (!file_exists($server_dir.$timestamp_redistrib))
-			mkdir($rep);
-		$dir = opendir($rep);
-		while($f = readdir($dir)){
-		   if(is_file($rep.$f))
-		     $zipfile -> addFile(implode("",file($rep.$f)),$sql_details['timestamp']."/".basename($rep.$f));
+		if (!file_exists($server_dir.$timestamp_redistrib)){
+			mkdir($server_dir.$timestamp_redistrib);
 		}
+		
+		$zipfile->open($server_dir.$timestamp_redistrib."/".$timestamp_redistrib."_redistrib.zip", ZipArchive::CREATE);
+		$zipfile->addEmptyDir($sql_details['timestamp']);
+		
+		$dir = opendir($rep);
+		
+		while($f = readdir($dir)){
+		   if(is_file($rep.$f)){
+		   	$zipfile -> addFile($rep.$f,$sql_details['timestamp']."/".basename($rep.$f));
+		   }
+		}
+		
+		$zipfile -> close();
+		
 		closedir($dir);
 		flush();
-		$handinfo = fopen( $server_dir.$timestamp_redistrib."/".$timestamp_redistrib."_redistrib.zip", "w+" );
-		fwrite( $handinfo, $zipfile -> file() );
-		fclose( $handinfo );
-	
+		
 		//crypt the file
 		$digest=crypt_file($server_dir.$timestamp_redistrib."/".$timestamp_redistrib."_redistrib.zip",$protectedPost["digest_algo"],$protectedPost["digest_encod"]);
 		//change name of this file to "tmp" for use function of create a package
@@ -107,6 +114,7 @@ if( isset( $protectedPost["VALID_END"] ) ) {
 						'NEED_DONE_ACTION'=>'0',
 						'NEED_DONE_ACTION_TEXT'=>'',
 						'GARDEFOU'=>"rien");
+		
 		create_pack($sql_details,$info_details);
 	}
 	unset($protectedPost,$_SESSION['OCS']['DATA_CACHE']);
@@ -120,14 +128,12 @@ echo open_form($form_name,'',"enctype='multipart/form-data'");
 
 if (isset($protectedPost['valid'])){
 	looking4config();
-
-	$fSize = @filesize( $_FILES["teledeploy_file"]["tmp_name"]);
-	//file not exist
-	if( $fSize <= 0 ){
-		if ($protectedPost['ACTION'] != 'EXECUTE') 
-			$error=$l->g(436)." ".$_FILES["teledeploy_file"]["tmp_name"];
-	}//file exist
-	else{
+	
+	
+	
+	//file exist
+	if (file_exists($_FILES["teledeploy_file"]["tmp_name"]) && is_readable($_FILES["teledeploy_file"]["tmp_name"])
+									&& filesize($_FILES["teledeploy_file"]["tmp_name"]) > 0){
 		//is it a zip file or TAR.GZ file?
 		$name_file_extention=explode('.',$_FILES["teledeploy_file"]["name"]);
 		$extention=array_pop($name_file_extention);
@@ -138,12 +144,17 @@ if (isset($protectedPost['valid'])){
 			$error=$l->g(1232);
 		}		
 	}
+	//file not exist
+	else{
+		if ($protectedPost['ACTION'] != 'EXECUTE')
+			$error=$l->g(436)." ".$_FILES["teledeploy_file"]["tmp_name"];
+	}
 	
 	//the package name is exist in database?
 	$verifN = "SELECT fileid FROM download_available WHERE name='%s'";
 	$argverifN=$protectedPost["NAME"];
 	$resN = mysql2_query_secure( $verifN, $_SESSION['OCS']["readServer"], $argverifN);
-	if( mysql_num_rows( $resN ) != 0 )
+	if( mysqli_num_rows( $resN ) != 0 )
 	$error=$l->g(551);
 	
 	
@@ -211,7 +222,7 @@ if (isset($protectedPost['valid'])){
 		
 	//get the file
 	if (!($_FILES["teledeploy_file"]["size"]== 0 and $protectedPost['ACTION'] == 'EXECUTE')){
-		$size = $_FILES["teledeploy_file"]["size"];
+		$size = filesize($_FILES["teledeploy_file"]["tmp_name"]);
 		//crypt the file
 		$digest=crypt_file($_FILES["teledeploy_file"]["tmp_name"],$protectedPost["digest_algo"],$protectedPost["digest_encod"]);
 		//create temp file
@@ -278,7 +289,7 @@ if (!$protectedPost){
 		$document_root = $val_document_root["tvalue"]['DOWNLOAD_PACK_DIR']."/download/";
 	else{	
 		//if no directory in base, take $_SERVER["DOCUMENT_ROOT"]
-		$document_root = DOCUMENT_ROOT."download/";
+		$document_root = VARLIB_DIR.'/download/';
 	}
 
 	$rep_exist=file_exists($document_root); 
@@ -405,52 +416,7 @@ echo " style='display:none;'";
 echo ">";
 printEnTete($l->g(434));
 echo "<br>";
-$activate=option_conf_activate('TELEDIFF_WK');
 
-//If workflow for teledeploy is activated
-//We show only the package we can create
-if ($activate){
-	msg_info($l->g(1105)."<br>".$l->g(1106)."<br>".$l->g(1107));
-	
-	//get all request with the status "Create a Package"
-	$conf_creat_Wk=look_config_default_values(array('IT_SET_NIV_CREAT'));
-	$info_dde_statut_creat=info_dde(find_dde_by_status($conf_creat_Wk['tvalue']['IT_SET_NIV_CREAT']));
-	if ($info_dde_statut_creat != ''){
-		$array_id_fields=find_id_field(array('NAME_TELEDEPLOY','PRIORITY','NOTIF_USER','REPORT_USER','INFO_PACK'));
-	
-		//build the seach
-		$id_name="fields_".$array_id_fields['NAME_TELEDEPLOY']->id;
-		$id_description="fields_".$array_id_fields['INFO_PACK']->id;
-		$id_priority="fields_".$array_id_fields['PRIORITY']->id;
-		$id_notify_user="fields_".$array_id_fields['NOTIF_USER']->id;
-		
-		foreach ($info_dde_statut_creat as $id=>$tab_value){
-			$list_dde_creat[$tab_value->ID]=$tab_value->$id_name;
-		}
-		echo "<br><b>" . $l->g(1183) . ":</b>".show_modif($list_dde_creat,'LIST_DDE_CREAT',2,$form_name);
-		if (!$protectedPost['LIST_DDE_CREAT'] or $protectedPost['LIST_DDE_CREAT'] == ""){
-			echo close_form();
-			require_once(FOOTER_HTML);
-			die();
-		}else{
-			$protectedPost['NAME']=$info_dde_statut_creat[$protectedPost['LIST_DDE_CREAT']]->$id_name;
-			$protectedPost['DESCRIPTION']=$info_dde_statut_creat[$protectedPost['LIST_DDE_CREAT']]->$id_description;
-			$NAME_TYPE=3;
-			$DESCRIPTION_TYPE=3;
-			
-		}
-	}else{
-		echo close_form();
-		require_once(FOOTER_HTML);
-		die();
-	}
-	
-	
-}else{
-	$NAME_TYPE=0;
-	$DESCRIPTION_TYPE=1;
-	
-}
 $config_input=array('MAXLENGTH'=>255,'SIZE'=>50);
 $title_creat="<tr height='30px'><td colspan='10' align='center'><b>".$l->g(438)."</b></td></tr>";
 $title_user="<tr height='30px' BGCOLOR='#C7D9F5'><td align='center' colspan='10'><b>".$l->g(447)."</b></td></tr>";
@@ -493,8 +459,7 @@ $redistrib="<tr height='30px' bgcolor='white'><td colspan='2'>".$l->g(1008).":</
 echo "<table BGCOLOR='#C7D9F5' BORDER='0' WIDTH = '600px' ALIGN = 'Center' CELLPADDING='0' BORDERCOLOR='#9894B5' >";
 
 echo $title_creat.$nom.$descr;
-if (isset($_SESSION['OCS']['RESTRICTION']['TELEDIFF_VISIBLE']) 
-	and $_SESSION['OCS']['RESTRICTION']['TELEDIFF_VISIBLE'] == "NO" )
+if ($_SESSION['OCS']['profile']->getRestriction('TELEDIFF_VISIBLE', 'NO') == "NO" )
 echo $visible;
 echo $os.$proto.$prio.$file.$action;
 //redistrib
@@ -504,7 +469,7 @@ if ($_SESSION['OCS']["use_redistribution"] == 1){
 	$sql="select NAME,TVALUE from config where NAME ='DOWNLOAD_REP_CREAT'
 		  union select NAME,TVALUE from config where NAME ='DOWNLOAD_SERVER_DOCROOT'";
 	$resdefaultvalues = mysql2_query_secure( $sql, $_SESSION['OCS']["readServer"]);
-	while($item = mysql_fetch_object($resdefaultvalues))
+	while($item = mysqli_fetch_object($resdefaultvalues))
 			$default[$item ->NAME]=$item ->TVALUE;
 	if (!$default['DOWNLOAD_REP_CREAT'])
 	$default['DOWNLOAD_REP_CREAT'] = $_SERVER["DOCUMENT_ROOT"]."/download/server/";
