@@ -12,7 +12,7 @@
 
 require('require/function_stats.php');
 
-if($_SESSION['OCS']['CONFIGURATION']['TELEDIFF']=="YES" 
+if($_SESSION['OCS']['profile']->getConfigValue('TELEDIFF')=="YES" 
 	and isset($protectedPost["ACTION"]) and $protectedPost["ACTION"] != ''){
 
 	if( $protectedPost["ACTION"] == "VAL_SUCC") {	
@@ -41,7 +41,7 @@ echo open_form($form_name);
 $sql="SELECT name FROM download_available WHERE fileid='%s'";
 $arg=$protectedGet["stat"];
 $res =mysql2_query_secure($sql, $_SESSION['OCS']["readServer"],$arg);		
-$row=mysql_fetch_object($res);
+$row=mysqli_fetch_object($res);
 printEnTete( $l->g(498)." <b>".$row -> name."</b> (".$l->g(296).": ".$protectedGet["stat"]." )");
 
 
@@ -54,7 +54,7 @@ $sql_count="SELECT COUNT(id) as nb
 				AND hardware_id NOT IN (SELECT id FROM hardware WHERE deviceid='_SYSTEMGROUP_' or deviceid='_DOWNLOADGROUP_')";
 $arg=$protectedGet["stat"];
 $rescount =mysql2_query_secure($sql_count, $_SESSION['OCS']["readServer"],$arg);	
-$row=mysql_fetch_object($rescount);
+$row=mysqli_fetch_object($rescount);
 $total=$row->nb;
 if ($total<=0){
 	msg_error($l->g(837));
@@ -92,7 +92,7 @@ if ($total<=0){
 $arg=array($arg,'EXIT_CODE%','ERR%',$l->g(573),$arg,'EXIT_CODE%','ERR%',$l->g(482),$arg);
 $resStats =mysql2_query_secure($sqlStats." ORDER BY nb DESC", $_SESSION['OCS']["readServer"],$arg);		
 $i=0;
-while ($row=mysql_fetch_object($resStats)){
+while ($row=mysqli_fetch_object($resStats)){
 	$txt_status=strtoupper ($row->txt);
 	$name_value[$i] = $txt_status;
 	$pourc=round(($row->nb*100)/$total,2);
@@ -168,7 +168,7 @@ while ($row=mysql_fetch_object($resStats)){
 		</script>';	
 echo "</div><br>";
 
-if($_SESSION['OCS']['CONFIGURATION']['TELEDIFF']=="YES"){
+if($_SESSION['OCS']['profile']->getConfigValue('TELEDIFF')=="YES"){
 	echo "<table class='Fenetre' align='center' border='1' cellpadding='5' width='50%'><tr BGCOLOR='#C7D9F5'>";
 	echo "<td width='33%' align='center'><a OnClick='pag(\"VAL_SUCC\",\"ACTION\",\"".$form_name."\");'><b>".$l->g(483)."</b></a></td>";	
 	echo "<td width='33%' align='center'><a OnClick='pag(\"DEL_ALL\",\"ACTION\",\"".$form_name."\");'><b>".$l->g(571)."</b></a></td>";	
@@ -189,7 +189,7 @@ while( $j<$i ) {
 	echo "&nbsp;</td><td>".$name_value[$j]."</td><td>
 			<a href='index.php?".PAG_INDEX."=".$pages_refs['ms_multi_search']."&prov=stat&id_pack=".$protectedGet["stat"]."&stat=".urlencode($link[$j])."'>".$count_value[$j]."</a>";
 	if (substr_count($link[$j], 'SUC'))
-		echo "<a href=# onclick=window.open(\"index.php?".PAG_INDEX."=".$pages_refs['ms_speed_stat']."&head=1&ta=".urlencode($link[$j])."&stat=".$protectedGet["stat"]."\",\"stats_speed\",\"location=0,status=0,scrollbars=0,menubar=0,resizable=0,width=1000,height=900\")>&nbsp<img src='image/stat.png'></a>";		
+		echo "<a href=\"index.php?".PAG_INDEX."=".$pages_refs['ms_speed_stat']."&head=1&ta=".urlencode($link[$j])."&stat=".$protectedGet["stat"]."\">&nbsp<img src='image/stat.png'></a>";		
 	echo "	</td></tr>";
 	$j++;
 }
