@@ -8,7 +8,15 @@
 // code is always made freely available.
 // Please refer to the General Public Licence http://www.gnu.org/ or Licence.txt
 //====================================================================================
-
+if(AJAX){
+	parse_str($protectedPost['ocs']['0'], $params);
+	$protectedPost+=$params;
+	ob_start();
+	$ajax = true;
+}
+else{
+	$ajax=false;
+}
 function return_bytes($val) {
     $val = trim($val);
     $last = strtolower($val{strlen($val)-1});
@@ -54,13 +62,13 @@ echo "<script language='javascript'>
 			{
 				filenamenoext=namefile(filename);
 				if (filenamenoext != 'ocsagent' && filenamenoext != 'ocs-ng-windows-agent-setup' && filenamenoext != 'ocspackage' && ExtList[i] == 'exe'){
-					alert('".mysql_real_escape_string($l->g(1243))."');
+					alert('".mysqli_real_escape_string($_SESSION['OCS']["readServer"],$l->g(1243))."');
 					return (false);
 				}
 				return (true);
 			}
 		}
-		alert('".mysql_real_escape_string($l->g(168))."');
+		alert('".mysqli_real_escape_string($_SESSION['OCS']["readServer"],$l->g(168))."');
 		return (false);
      }
           
@@ -78,6 +86,10 @@ else
 echo "<br><center><font color=orange><b>" . $l->g(2040) . " " . $MaxAvail . $l->g(1240) . "<br>" . $l->g(2041) . "</b></font></center>";
 */
 $table_name=$form_name;
+
+$tab_options=$protectedPost;
+$tab_options['form_name']=$form_name;
+$tab_options['table_name']=$table_name;
 if (isset($_FILES['file_upload']['name'])){
 	if ($_FILES['file_upload']['size'] != 0){
 		$fname=$_FILES['file_upload']['name'];
@@ -94,7 +106,7 @@ if (isset($_FILES['file_upload']['name'])){
 		$arg=array($fname,$binary);
 		$result=mysql2_query_secure($sql,$_SESSION['OCS']["writeServer"],$arg);	
 		if (!$result)
-			msg_error($l->g(2003).mysql_errno($_SESSION['OCS']["writeServer"])."<br>".mysql_error($_SESSION['OCS']["writeServer"]));
+			msg_error($l->g(2003).mysqli_errno($_SESSION['OCS']["writeServer"])."<br>".mysqli_error($_SESSION['OCS']["writeServer"]));
 		else{
 			msg_success($l->g(137)." ".$_FILES['file_upload']['name']." ".$l->g(234));
 			$tab_options['CACHE']='RESET';
@@ -126,7 +138,7 @@ if (!isset($protectedPost['ADD_FILE'])){
 	$tab_options['POPUP_SIZE'][$l->g(49)]="width=900,height=600";
 	printEntete($l->g(1245));
 	echo "<br>";
-	tab_req($table_name,$list_fields,$default_fields,$list_col_cant_del,$sql,$form_name,80,$tab_options);
+	ajaxtab_entete_fixe($list_fields,$default_fields,$tab_options,$list_col_cant_del);
 	//echo show_modif($name,'ADD_FILE',8,"",$configinput=array('DDE'=>100));
 	echo "<input type=submit name=ADD_FILE value='".$l->g(1048)."'>";
 	echo close_form();
@@ -138,7 +150,7 @@ if (isset($protectedPost['ADD_FILE']) and $protectedPost['ADD_FILE'] != ''){
 	//search max_allowed_packet value on mysql conf
 	$sql="SHOW VARIABLES LIKE 'max_allowed_packet'";
 	$result=mysql2_query_secure($sql,$_SESSION['OCS']["readServer"]);
-	$value=mysql_fetch_array($result);
+	$value=mysqli_fetch_array($result);
 	//pass oct to Mo
 	$upload_max_filesize=$value['Value']/1048576;
 
@@ -155,5 +167,8 @@ if (isset($protectedPost['ADD_FILE']) and $protectedPost['ADD_FILE'] != ''){
 
 }
 
-
+if ($ajax){
+	ob_end_clean();
+	tab_req($list_fields,$default_fields,$list_col_cant_del,$sql,$tab_options);
+}
 ?>
