@@ -9,21 +9,24 @@
 // Please refer to the General Public Licence http://www.gnu.org/ or Licence.txt
 //====================================================================================
 
+require_once 'require/function_users.php';
 
-require_once('require/function_users.php');
-if (isset($protectedPost['Valid_modif_x'])){
+if (isset($protectedPost['Valid_modif'])) {
 	$protectedPost['ACCESSLVL']=$_SESSION['OCS']['lvluser'];
 	$protectedPost['ID']=$_SESSION['OCS']["loggeduser"];
 	$protectedPost['MODIF']=$_SESSION['OCS']["loggeduser"];
-	$msg=add_user($protectedPost);	
-	if ($msg != $l->g(374))
+	
+	$msg = add_user($_POST, get_profile_labels());
+	if ($msg != $l->g(374)) {
 		msg_error($msg);
-	else
+	} else {
 		msg_success($l->g(1186));
+	}
 }
+
 $form_name="pass";
-echo "<br>";
 echo open_form($form_name);
-admin_user($_SESSION['OCS']["loggeduser"]);
-echo close_form();
-?>	
\ No newline at end of file
+
+admin_user($_SESSION['OCS']["loggeduser"], true);
+
+echo close_form();
\ No newline at end of file
