@@ -20,12 +20,12 @@ if (isset($protectedPost['ADMIN']) and $protectedPost['ADMIN'] == 'ADMIN' and !i
 elseif (isset($protectedPost['ADMIN']) and $protectedPost['ADMIN'] == 'ADMIN' and isset($_SESSION['OCS']['ADMIN']['ACCOUNTINFO']))
 	unset($_SESSION['OCS']['ADMIN']['ACCOUNTINFO']);
 
-if ($_SESSION['OCS']['CONFIGURATION']['ACCOUNTINFO'] == 'YES' and isset($_SESSION['OCS']['ADMIN']['ACCOUNTINFO']))
+if ($_SESSION['OCS']['profile']->getConfigValue('ACCOUNTINFO') == 'YES' and isset($_SESSION['OCS']['ADMIN']['ACCOUNTINFO']))
 	$admin_accountinfo=true;
 	
 $list_tab=find_all_account_tab('TAB_ACCOUNTSNMP','SNMP',1);	
 if ($list_tab != ''){
-	if ($protectedPost['Valid_modif_x'] != ""){
+	if ($protectedPost['Valid_modif'] != ""){
 		foreach ($protectedPost as $field=>$value){
 			$temp_field=explode('_',$field);
 			if (array_key_exists( $temp_field[0] . '_' . $temp_field[1],$info_account_id) or $temp_field[0] == 'TAG'){
@@ -67,7 +67,7 @@ if ($list_tab != ''){
 	echo open_form($form_name);
 	onglet($list_tab,$form_name,"onglet",6);
 	echo '<div class="mlt_bordure" >';
-	if ($_SESSION['OCS']['CONFIGURATION']['ACCOUNTINFO'] == 'YES'){
+	if ($_SESSION['OCS']['profile']->getConfigValue('ACCOUNTINFO') == 'YES'){
 		$show_admin_button = "<a href=# OnClick='pag(\"ADMIN\",\"ADMIN\",\"".$form_name."\");'>";
 		if (isset($_SESSION['OCS']['ADMIN']['ACCOUNTINFO']))
 				$show_admin_button .= "<img src='image/success.png'></a>";
@@ -80,23 +80,23 @@ if ($list_tab != ''){
 						order by SHOW_ORDER ASC";
 	$arg_admin_info=array($protectedPost['onglet']);
 	$res_admin_info=mysql2_query_secure($sql_admin_info,$_SESSION['OCS']["readServer"],$arg_admin_info);
-	$num_row=mysql_num_rows($res_admin_info);
+	$num_row=mysqli_num_rows($res_admin_info);
 	$name_field=array();
 	$tab_name=array();
 	$type_field=array();
 	$value_field=array();
-	$config['COMMENT_BEHING']=array();
+	$config['COMMENT_AFTER']=array();
 	$config['SELECT_DEFAULT']=array();
 	$config['JAVASCRIPT']=array();
 	$config['SIZE']=array();
 	$config['DDE']=array();
 	
 	$nb_row=1;
-	while ($val_admin_info = mysql_fetch_array( $res_admin_info )){	
+	while ($val_admin_info = mysqli_fetch_array( $res_admin_info )){	
 		array_push($config['DDE'],$systemid);	
 		//if name_accountinfo is not null 
 		//column name in accountinfo table is name_accountinfo 
-		//functionnality for compatibily with older version of OCS
+		//functionality for compatibility with older version of OCS
 		//we can't change the name TAG in accountinfo table 
 		if ($val_admin_info['NAME_ACCOUNTINFO'] != '')
 			$name_accountinfo=trim($val_admin_info['NAME_ACCOUNTINFO']);
@@ -116,9 +116,9 @@ if ($list_tab != ''){
 				array_push($config['JAVASCRIPT'],'');
 				array_push($config['SIZE'],'');
 				if ($admin_accountinfo)
-					array_push($config['COMMENT_BEHING'],$up_png . "<a href=# onclick=window.open(\"index.php?".PAG_INDEX."=".$pages_refs['ms_adminvalues']."&head=1&tag=ACCOUNT_SNMP_VALUE_" . $val_admin_info['NAME'] . "\",\"ACCOUNT_SNMP_VALUE\",\"location=0,status=0,scrollbars=0,menubar=0,resizable=0,width=550,height=450\")><img src=image/plus.png></a>");
+					array_push($config['COMMENT_AFTER'],$up_png . "<a href=\"index.php?".PAG_INDEX."=".$pages_refs['ms_adminvalues']."&head=1&tag=ACCOUNT_SNMP_VALUE_" . $val_admin_info['NAME'] . "\"><img src=image/plus.png></a>");
 				else
-					array_push($config['COMMENT_BEHING'],'');
+					array_push($config['COMMENT_AFTER'],'');
 				array_push($config['SELECT_DEFAULT'],'YES');
 				$field_select_values=find_value_field("ACCOUNT_SNMP_VALUE_".$val_admin_info['NAME']);
 				array_push($value_field,$field_select_values);
@@ -137,18 +137,18 @@ if ($list_tab != ''){
 			}elseif ($val_admin_info['TYPE'] == 6){	
 				array_push($value_field,$info_account_id[$name_accountinfo]);
 				if ($admin_accountinfo)
-					array_push($config['COMMENT_BEHING'],$up_png . datePick($name_accountinfo));
+					array_push($config['COMMENT_AFTER'],$up_png . datePick($name_accountinfo));
 				else
-					array_push($config['COMMENT_BEHING'],datePick($name_accountinfo));
+					array_push($config['COMMENT_AFTER'],datePick($name_accountinfo));
 				array_push($config['JAVASCRIPT'],"READONLY ".dateOnClick($name_accountinfo));
 				array_push($config['SELECT_DEFAULT'],'');
 				array_push($config['SIZE'],'8');	
 			}elseif ($val_admin_info['TYPE'] == 5){
 				array_push($value_field,"accountinfo");
 				if ($admin_accountinfo)
-					array_push($config['COMMENT_BEHING'],$up_png);
+					array_push($config['COMMENT_AFTER'],$up_png);
 				else
-					array_push($config['COMMENT_BEHING'],"");
+					array_push($config['COMMENT_AFTER'],"");
 				array_push($config['SELECT_DEFAULT'],'');
 				array_push($config['JAVASCRIPT'],'');
 				array_push($config['SIZE'],'');
@@ -157,9 +157,9 @@ if ($list_tab != ''){
 			}else{
 				array_push($value_field,$info_account_id[$name_accountinfo]);
 				if ($admin_accountinfo)
-					array_push($config['COMMENT_BEHING'],$up_png);
+					array_push($config['COMMENT_AFTER'],$up_png);
 				else
-					array_push($config['COMMENT_BEHING'],"");
+					array_push($config['COMMENT_AFTER'],"");
 				array_push($config['SELECT_DEFAULT'],'');
 				array_push($config['JAVASCRIPT'],'');
 				array_push($config['SIZE'],'');
@@ -167,7 +167,7 @@ if ($list_tab != ''){
 			
 			array_push($name_field,$name_accountinfo);
 			array_push($tab_name,$val_admin_info['COMMENT']);
-			if ($_SESSION['OCS']['CONFIGURATION']['CHANGE_ACCOUNTINFO'] == "YES")
+			if ($_SESSION['OCS']['profile']->getConfigValue('CHANGE_ACCOUNTINFO') == "YES")
 				array_push($type_field,$convert_type[$val_admin_info['TYPE']]);
 			else
 				array_push($type_field,3);
@@ -177,11 +177,14 @@ if ($list_tab != ''){
 	}	
 	
 		$tab_typ_champ=show_field($name_field,$type_field,$value_field,$config);
-		if ($_SESSION['OCS']['CONFIGURATION']['ACCOUNTINFO'] == 'YES')
+		if ($_SESSION['OCS']['profile']->getConfigValue('ACCOUNTINFO') == 'YES')
 			$tab_hidden=array('ADMIN'=>'','UP'=>'','DOWN'=>'');
 		//echo "<input type='hidden' name='ADMIN' id='ADMIN' value=''>";
 		
-		tab_modif_values($tab_name,$tab_typ_champ,$tab_hidden,$title="",$comment="",$name_button="modif",$showbutton=true,$form_name='NO_FORM',$show_admin_button);
+		tab_modif_values($tab_name,$tab_typ_champ,$tab_hidden, array(
+			'form_name' => 'NO_FORM',
+			'top_action' => $show_admin_button
+		));
 	
 	echo "</div>"; 
 	echo close_form();
