@@ -8,17 +8,29 @@
 // code is always made freely available.
 // Please refer to the General Public Licence http://www.gnu.org/ or Licence.txt
 //====================================================================================
-
-/*
- * 
- * Show sd_powersupplies data
- * 
- */
-
+	/*
+	 * 
+	 * Show sd_powersupplies data
+	 * 
+	 */
+	if(AJAX){
+		ob_end_clean();
+		parse_str($protectedPost['ocs']['0'], $params);
+		$protectedPost+=$params;
+		ob_start();
+		$ajax = true;
+	}
+	else{
+		$ajax=false;
+	}
 	print_item_header($l->g(1223));
 	if (!isset($protectedPost['SHOW']))
 		$protectedPost['SHOW'] = 'NOSHOW';
 	$table_name="sd_powersupplies";
+	$tab_options=$protectedPost;
+	$tab_options=$protectedPost;
+	$tab_options['form_name']=$form_name;
+	$tab_options['table_name']=$table_name;
 	$list_fields=array($l->g(64)=>'MANUFACTURER', 
 					   'REFERENCE'=>'REFERENCE',
 					   $l->g(66) => 'TYPE',
@@ -34,7 +46,10 @@
 	$sql['ARG'][]='snmp_powersupplies';
 	$sql['ARG'][]=$systemid;
 	$tab_options['ARG_SQL']=$sql['ARG'];
-	tab_req($table_name,$list_fields,$default_fields,$list_col_cant_del,$sql['SQL'],$form_name,80,$tab_options);
-
-
+	ajaxtab_entete_fixe($list_fields,$default_fields,$tab_options,$list_col_cant_del);
+	if ($ajax){
+		ob_end_clean();
+		tab_req($list_fields,$default_fields,$list_col_cant_del,$sql['SQL'],$tab_options);
+		ob_start();	
+	}
 ?>
\ No newline at end of file
