@@ -14,7 +14,7 @@ $type_accountinfo=array('TEXT','TEXTAREA','SELECT',
 					mb_strtoupper($l->g(802)),'CHECKBOX',
 					'BLOB (FILE)','DATE','RADIOBUTTON','QRCODE');
 $sql_type_accountinfo=array('VARCHAR(255)','LONGTEXT','VARCHAR(255)',
-							'VARCHAR(255)','VARCHAR(255)','BLOB','VARCHAR(10)',
+							'VARCHAR(255)','VARCHAR(255)','BLOB','DATE',
 							'VARCHAR(255)','VARCHAR(255)');
 
 
@@ -52,7 +52,7 @@ function max_order($table,$field){
 	$sql="SELECT max(%s) as max_id FROM %s";
 	$arg=array($field,$table);
 	$result=mysql2_query_secure($sql,$_SESSION['OCS']["readServer"],$arg);			
-	$val = mysql_fetch_array( $result );
+	$val = mysqli_fetch_array( $result );
 	return $val['max_id']+1;
 }
 
@@ -92,7 +92,7 @@ function add_accountinfo($newfield,$newtype,$newlbl,$tab,$type='COMPUTERS',$defa
 		mysql2_query_secure($sql_insert_config,$_SESSION['OCS']["writeServer"],$arg_insert_config);					
 		
 		$sql_add_column="ALTER TABLE ".$table." ADD COLUMN fields_%s %s default NULL";
-		$arg_add_column=array(mysql_insert_id($_SESSION['OCS']["writeServer"]),$sql_type_accountinfo[$newtype]);
+		$arg_add_column=array(mysqli_insert_id($_SESSION['OCS']["writeServer"]),$sql_type_accountinfo[$newtype]);
 		mysql2_query_secure($sql_add_column,$_SESSION['OCS']["writeServer"],$arg_add_column);			
 		unset($newfield,$newlbl,$_SESSION['OCS']['TAG_LBL']);
 		//msg_success($l->g(1069));
@@ -117,7 +117,7 @@ function del_accountinfo($id){
 	$sql_found_account_type="SELECT account_type FROM accountinfo_config WHERE id = '%s'";
 	$arg_found_account_type=$id;
 	$result= mysql2_query_secure($sql_found_account_type,$_SESSION['OCS']["readServer"],$arg_found_account_type);		
-	$val = mysql_fetch_array( $result );
+	$val = mysqli_fetch_array( $result );
 	if ($val['account_type'] == "SNMP")
 		$table="snmp_accountinfo";
 	elseif ($val['account_type'] == "COMPUTERS")
@@ -162,7 +162,7 @@ function find_all_account_tab($tab_value,$onlyactiv='',$first=''){
 	$arg_tab_account=$tab_value.'%';
 	
 	$result_tab_account=mysql2_query_secure($sql_tab_account,$_SESSION['OCS']["readServer"],$arg_tab_account);					
-	while ($val_tab_account = mysql_fetch_array( $result_tab_account )){
+	while ($val_tab_account = mysqli_fetch_array( $result_tab_account )){
 		if (!isset($array_tab_account['FIRST']) and $first != '')
 		$array_tab_account['FIRST']=$val_tab_account['IVALUE'];
 		$array_tab_account[$val_tab_account['IVALUE']]=$val_tab_account['TVALUE'];		
@@ -222,7 +222,7 @@ function find_info_accountinfo($id = '',$type='',$exclu_type=''){
 	}
 	
 	$result_info_account=mysql2_query_secure($sql_info_account,$_SESSION['OCS']["readServer"],$arg_info_account);					
-	while ($val_info_account = mysql_fetch_array( $result_info_account )){
+	while ($val_info_account = mysqli_fetch_array( $result_info_account )){
 		$array_info_account[$val_info_account['id']]=$val_info_account;		
 	}	
 	 return $array_info_account;	
@@ -239,7 +239,7 @@ function witch_field_more($account_type = ''){
 		$sql_accountinfo.= " where account_type = '".$account_type."' ";
 	$result_accountinfo = mysql2_query_secure($sql_accountinfo,$_SESSION['OCS']["readServer"]);
 	
-	while($item = mysql_fetch_object($result_accountinfo)){
+	while($item = mysqli_fetch_object($result_accountinfo)){
 		$list_fields[$item->ID]=$item->COMMENT;
 		$list_name[$item->ID]=$item->NAME;
 		$list_type[$item->ID]=$item->TYPE;
@@ -291,7 +291,7 @@ function find_new_order($updown,$id,$type,$onglet){
 	$sql="select ID,SHOW_ORDER from accountinfo_config where account_type='%s' and id_tab=%s order by show_order";
 	$arg=array($type,$onglet);
 	$result = mysql2_query_secure($sql,$_SESSION['OCS']["readServer"],$arg);
-	while($item = mysql_fetch_object($result)){
+	while($item = mysqli_fetch_object($result)){
 		$array_id[]=$item->ID;
 		$array_order[]=$item->SHOW_ORDER;
 	}
@@ -354,7 +354,7 @@ function dde_exist($name,$id='',$type){
 				array_push($arg_verif,$id);
 			}			
 			$res_verif=mysql2_query_secure($sql_verif,$_SESSION['OCS']["readServer"],$arg_verif);
-			$val_verif = mysql_fetch_array( $res_verif );
+			$val_verif = mysqli_fetch_array( $res_verif );
 			//this name is already exist
 			if ($val_verif['c'] > 0)
 				return $l->g(1067);				
@@ -385,7 +385,7 @@ function admininfo_computer($id = ""){
 		$sql_account_data.= " LIMIT 1 ";
 	
 	$res_account_data=mysql2_query_secure($sql_account_data,$_SESSION['OCS']["readServer"],$arg_account_data);
-	$val_account_data = mysql_fetch_array( $res_account_data );
+	$val_account_data = mysqli_fetch_array( $res_account_data );
 	if (is_array($val_account_data))
 		return $val_account_data;	
 	else
@@ -481,7 +481,7 @@ function show_accountinfo($id='',$type='',$exclu_type =''){
 								 'type_field'=> $type_field,
 								 'value_field'=>$value_field),
 				'CONFIG'=>$config,
-				'COMMENT_BEHING'=>$comment_behing);
+				'COMMENT_AFTER'=>$comment_behing);
 	
 	
 }
