@@ -21,8 +21,8 @@ function look_config_default_values($field_name,$like='',$default_values=''){
 		$arg['SQL']="select NAME,IVALUE,TVALUE,COMMENTS from config where NAME like '%s'";
 		$arg['ARG']=$field_name;		
 	}
-	$resdefaultvalues=mysql2_query_secure($arg['SQL'],$_SESSION['OCS']["readServer"],$arg['ARG']);		
-	while($item = mysql_fetch_object($resdefaultvalues)){
+	$resdefaultvalues=mysql2_query_secure($arg['SQL'],$_SESSION['OCS']["readServer"],$arg['ARG']);
+	while($item = mysqli_fetch_object($resdefaultvalues)){
 			$result['name'][$item ->NAME]=$item ->NAME;
 			$result['ivalue'][$item ->NAME]=$item ->IVALUE;
 			$result['tvalue'][$item ->NAME]=$item ->TVALUE;
@@ -50,11 +50,11 @@ function look_config_default_values($field_name,$like='',$default_values=''){
 function generate_secure_sql($sql,$arg=''){
 	if (is_array($arg)){
 		foreach ($arg as $key=>$value){			
-				$arg_array_escape_string[]=mysql_real_escape_string($value);
+				$arg_array_escape_string[]=mysqli_real_escape_string($_SESSION['OCS']["readServer"],$value);
 		}
 		$arg_escape_string=$arg_array_escape_string;
 	}elseif ($arg != ''){	
-			$arg_escape_string=mysql_real_escape_string($arg);
+			$arg_escape_string=mysqli_real_escape_string($_SESSION['OCS']["readServer"],$arg);
 	}
 	if (isset($arg_escape_string)){
 		if (is_array($arg_escape_string)){
@@ -91,9 +91,9 @@ function mysql2_query_secure($sql,$link,$arg='',$log=false){
 			return false;		
 		 }
 	}
-	$result=mysql_query( $query, $link );
+	$result=mysqli_query( $link,$query );
 	if ($_SESSION['OCS']['DEBUG'] == 'ON' and !$result)
-		msg_error(mysql_error($link));
+		msg_error(mysqli_error($link));
 	return $result;
 }
 
@@ -143,20 +143,25 @@ function prepare_sql_tab($list_fields,$explu=array(),$distinct=false){
  }
  
 function dbconnect($server,$compte_base,$pswd_base,$db = DB_NAME) {
-	
+	error_reporting(E_ALL & ~E_NOTICE);
+	mysqli_report(MYSQLI_REPORT_STRICT);
 	//$link is ok?
-	$link=@mysql_connect($server,$compte_base,$pswd_base);
-	if(!is_resource($link)) {
-		return  "ERROR: MySql connection problem<br>".mysql_error();
+	try{
+		$link = mysqli_connect($server,$compte_base,$pswd_base);
+	} catch (Exception $e){
+		if(mysqli_connect_errno()) {
+			return  "ERROR: MySql connection problem ".$e->getCode()."<br>".$e->getMessage();
+		}
 	}
 	//database is ok?
-	if( ! mysql_select_db($db,$link)) {
+	if( ! mysqli_select_db($link,$db)) {
 		return "NO_DATABASE";
 	}
 	//force UTF-8
-	mysql_query("SET NAMES 'utf8'");
+	mysqli_query($link,"SET NAMES 'utf8'");
 	//sql_mode => not strict
-	mysql_query("SET sql_mode='NO_AUTO_CREATE_USER,NO_ENGINE_SUBSTITUTION'");
+	mysqli_query($link,"SET sql_mode='NO_AUTO_CREATE_USER,NO_ENGINE_SUBSTITUTION'");
+
 	return $link;
 }
 
@@ -166,15 +171,17 @@ function dbconnect($server,$compte_base,$pswd_base,$db = DB_NAME) {
 function addLog( $type, $value="",$lbl_sql='') {
 	//global $logHandler;
 	if ($_SESSION['OCS']['LOG_GUI'] == 1){
-		$logHandler = @fopen( LOG_FILE, "a");
-		$dte = getDate();
-		$date = sprintf("%02d/%02d/%04d %02d:%02d:%02d", $dte["mday"], $dte["mon"], $dte["year"], $dte["hours"], $dte["minutes"], $dte["seconds"]); 
-		if ($lbl_sql != ''){
-			$value=$lbl_sql.' => '.$value;
+		if (is_writable(LOG_FILE)){
+			$logHandler = fopen( LOG_FILE, "a");
+			$dte = getDate();
+			$date = sprintf("%02d/%02d/%04d %02d:%02d:%02d", $dte["mday"], $dte["mon"], $dte["year"], $dte["hours"], $dte["minutes"], $dte["seconds"]); 
+			if ($lbl_sql != ''){
+				$value=$lbl_sql.' => '.$value;
+			}
+			$towite=$_SESSION['OCS']["loggeduser"].";".$date.";".DB_NAME.";".$type.";".$value.";".$_SERVER['REMOTE_ADDR'].";\n";
+			fwrite($logHandler,$towite);
+			fclose($logHandler);
 		}
-		$towite=$_SESSION['OCS']["loggeduser"].";".$date.";".DB_NAME.";".$type.";".$value.";".$_SERVER['REMOTE_ADDR'].";\n";
-		@fwrite($logHandler,$towite);
-		@fclose($logHandler);
 	}
 }
 
@@ -191,7 +198,6 @@ function dateTimeFromMysql($v) {
 
 
 function dateToMysql($date_cible) {
-
 	global $l;
 	if(!isset($date_cible)) return "";
 	
@@ -236,6 +242,7 @@ function read_config_file($writable=''){
 	$ms_cfg_file= $_SESSION['OCS']['CONF_PROFILS_DIR']."4all_config.txt";
 	$search=array('ORDER_FIRST_TABLE'=>'MULTI2',
 				  'ORDER_SECOND_TABLE'=>'MULTI2',
+				  'ORDER'=>'MULTI2',
 				  'LBL'=>'MULTI',
 				  'MENU'=>'MULTI',
 				  'MENU_TITLE'=>'MULTI',
@@ -268,22 +275,41 @@ function replace_language($info){
 			return $info;
 }
 
-function msg($txt,$css,$log=0){
-	echo "<center><div class='" . $css . "'>" . $txt . "</div></center>";	
-	if ($css == 'error')
-		addLog('MSG_'.$css, $txt);
+function msg($txt,$css,$closeid=false){
+	global $protectedPost;
+	
+	if (isset($protectedPost['close_alert']) and $protectedPost['close_alert'] != '')
+		$_SESSION['OCS']['CLOSE_ALERT'][$protectedPost['close_alert']]=1;
+	
+	if (!$_SESSION['OCS']['CLOSE_ALERT'][$closeid]){
+		echo "<center><div id='my-alert-" . $closeid . "' class='alert alert-" . $css . " fade in' role='alert'>";
+		if ($closeid != false)
+		echo "<button type='button' class='close' data-dismiss='alert'><span aria-hidden='true'>×</span><span class='sr-only'>Close</span></button>";
+		echo  $txt . "</div></center>";
+		if ($closeid != false){
+			echo "<script>$('#my-alert-" . $closeid . "').on('closed.bs.alert', function () {
+			 pag('" . $closeid . "','close_alert','close_msg');
+			})</script>";
+			
+			echo open_form('close_msg');
+			echo "<input type='hidden' name='close_alert' id='close_alert' value=''>";
+			echo close_form();
+		}
+		if ($css == 'error')
+			addLog('MSG_'.$css, $txt);
+	}
 }
-function msg_info($txt){
-	msg($txt,'info');
+function msg_info($txt,$close=false){
+	msg($txt,'info',$close);
 }
-function msg_success($txt){
-	msg($txt,'success');
+function msg_success($txt,$close=false){
+	msg($txt,'success',$close);
 }
-function msg_warning($txt){
-	msg($txt,'warning');
+function msg_warning($txt,$close=false){
+	msg($txt,'warning',$close);
 }
-function msg_error($txt){
-	msg($txt,'error');
+function msg_error($txt,$close=false){
+	msg($txt,'danger',$close);
 	return true;
 }
 
@@ -325,44 +351,79 @@ function html_header($no_java=false){
 			<head>
 				<TITLE>OCS Inventory</TITLE>
 				<LINK REL='shortcut icon' HREF='favicon.ico' />
-				<LINK REL='StyleSheet' TYPE='text/css' HREF='css/ocsreports.css'>";
+				<LINK REL='StyleSheet' TYPE='text/css' HREF='css/bootstrap.min.css'>
+				<LINK REL='StyleSheet' TYPE='text/css' HREF='css/bootstrap-theme.min.css'>
+				<LINK REL='StyleSheet' TYPE='text/css' HREF='css/bootstrap-custom.css'>
+				<LINK REL='StyleSheet' TYPE='text/css' HREF='css/dataTables-custom.css'>
+				<LINK REL='StyleSheet' TYPE='text/css' HREF='css/dataTables.bootstrap.css'>
+				<LINK REL='StyleSheet' TYPE='text/css' HREF='css/ocsreports.css'>
+				<LINK REL='StyleSheet' TYPE='text/css' HREF='css/header.css'>
+				<LINK REL='StyleSheet' TYPE='text/css' HREF='css/computer_details.css'>
+				<LINK REL='StyleSheet' TYPE='text/css' HREF='css/forms.css'>
+				";
 	if (!$no_java){
 		incPicker(); 
-		echo "<script language='javascript' type='text/javascript' src='js/function.js'></script>";
+		
 		//js for graph
-		echo "<script src='js/graph/jquery-1.6.2.js' type='text/javascript'></script>";
+		echo "<script src='js/jquery-1.11.0.js' type='text/javascript'></script>";
+		echo "<script src='js/jquery-migrate-1.2.1.min.js' type='text/javascript'></script>";
+		echo "<script src='js/jquery.ui.widget.js'></script>";
+		echo "<script src='js/jquery.iframe-transport.js'></script>";
+		echo "<script src='js/jquery.fileupload.js'></script>";
+		
+		echo "<script src='js/bootstrap.min.js' type='text/javascript'></script>";
+		echo "<script src='js/bootstrap-custom.js' type='text/javascript'></script>";
+		
   		echo "<script src='js/graph/raphael.js' type='text/javascript'></script>";
   		echo "<script src='js/graph/elycharts.js' type='text/javascript'></script>";
+  		
+  		//js for Datatables 
+  		echo "<script src='libraries/datatable/media/js/jquery.dataTables.js' type='text/javascript'></script>";
+  		echo "<script src='js/dataTables.bootstrap.js' type='text/javascript'></script>";
+
+  		echo "<script language='javascript' type='text/javascript' src='js/function.js'></script>";
+  			
+  		
 		if (isset($_SESSION['OCS']['JAVASCRIPT'])){
-			foreach ($_SESSION['OCS']['JAVASCRIPT'] as $file => $rep){
-				echo "<script language='javascript' type='text/javascript' src='".MAIN_SECTIONS_DIR.$rep.$file."'></script>";
+			foreach ($_SESSION['OCS']['JAVASCRIPT'] as $file){
+				echo "<script language='javascript' type='text/javascript' src='".MAIN_SECTIONS_DIR.$file."'></script>";
 			}
 		}
 	}
+	
 	echo "</head>"; 
 
 	echo "<body bottommargin='0' leftmargin='0' topmargin='0' rightmargin='0' marginheight='0' marginwidth='0'>";
 
 }
+
 function strip_tags_array($value='')
 {
+	
+	if(is_object($value)){
+		$value = get_class($value);
+		$value = strip_tags($value,"<p><b><i><font><br><center>");
+		$value = "Objet de la classe ".$value;
+		return $value;
+	}
 	$value = is_array($value) ? array_map('strip_tags_array', $value) : strip_tags($value,"<p><b><i><font><br><center>");
 	return $value;
 }
 
 function open_form($form_name,$action='',$more=''){
-	if (!isset($_SESSION['OCS']['CSRFNUMBER']) or !is_numeric($_SESSION['OCS']['CSRFNUMBER']) or $_SESSION['OCS']['CSRFNUMBER'] >= CSRF)
-		$_SESSION['OCS']['CSRFNUMBER'] = 0;
-	$form="<form name='".$form_name."' id='".$form_name."' method='POST' action='".$action."' ".$more." >";
-	$csrf_value = sha1(microtime());
-	$_SESSION['OCS']['CSRF'][$_SESSION['OCS']['CSRFNUMBER']] = $csrf_value;
-	$form.="<input type='hidden' name='CSRF_".$_SESSION['OCS']['CSRFNUMBER']."' id='CSRF_".$_SESSION['OCS']['CSRFNUMBER']."' value='".$csrf_value."'>";
-	$_SESSION['OCS']['CSRFNUMBER']++;
-	return $form;
+ 	if (!isset($_SESSION['OCS']['CSRFNUMBER']) or !is_numeric($_SESSION['OCS']['CSRFNUMBER']) or $_SESSION['OCS']['CSRFNUMBER'] >= CSRF)
+ 		$_SESSION['OCS']['CSRFNUMBER'] = 0;
+ 	$form="<form name='".$form_name."' id='".$form_name."' method='POST' action='".$action."' ".$more." >";
+ 	$csrf_value = sha1(microtime());
+ 	$_SESSION['OCS']['CSRF'][$_SESSION['OCS']['CSRFNUMBER']] = $csrf_value;
+ 	$form.="<input type='hidden' name='CSRF_".$_SESSION['OCS']['CSRFNUMBER']."' id='CSRF_".$_SESSION['OCS']['CSRFNUMBER']."' value='".$csrf_value."'>";
+ 	$_SESSION['OCS']['CSRFNUMBER']++;
+ 	return $form;
 }
 
 function close_form(){
 	return "</form>";	
 }
 
-?>
\ No newline at end of file
+
+?>
