@@ -14,7 +14,7 @@ require_once('require/function_ipdiscover.php');
 if ($_SESSION['OCS']["TAGS"]){	
 	$sql_tag=mysql2_prepare('select id from hardware h, accountinfo a where a.hardware_id=h.id and a.tag in ',array(),$_SESSION['OCS']["TAGS"]);
 	$result=mysql2_query_secure($sql_tag['SQL'],$_SESSION['OCS']["readServer"],$sql_tag['ARG']);
-	while ($val = mysql_fetch_object($result)){
+	while ($val = mysqli_fetch_object($result)){
 		$my_id[]=$val->id;	
 	}
 	$myids=mysql2_prepare('',array(),$my_id);
@@ -267,7 +267,7 @@ function define_tab($data_on=array()){
 	$data_on['SOFT']=mb_strtoupper($l->g(20), 'UTF-8');
 	$data_on['HARD']=mb_strtoupper($l->g(799), 'UTF-8');
 	$data_on['ELSE']=mb_strtoupper($l->g(800), 'UTF-8');
-	if( $_SESSION['OCS']['CONFIGURATION']['CONSOLE']=="YES") {
+	if( $_SESSION['OCS']['profile']->getConfigValue('CONSOLE')=="YES") {
 		//$data_on['ADMIN']['CONFIG']=mb_strtoupper($l->g(107));
 		$data_on['ADMIN']['MSG']=mb_strtoupper($l->g(915), 'UTF-8');
 	
@@ -384,7 +384,7 @@ function show_console_field($fields,$form_name){
 			if (!isset($_SESSION['OCS']['COUNT_CONSOLE'][$key])){
 				$res=mysql2_query_secure($sql_result,$_SESSION['OCS']["readServer"],$arg_result);
 				if ($res){
-					$count = mysql_fetch_object($res);
+					$count = mysqli_fetch_object($res);
 					$_SESSION['OCS']['COUNT_CONSOLE'][$key]=$count->c;
 				}
 			}
@@ -397,7 +397,7 @@ function show_console_field($fields,$form_name){
 							//'ARG'=>'&fields=HARDWARE-LASTCOME&comp=tall&values='.date($l->g(1242))
 							$link_me_begin.="&fields=".$multi_search[$key]['FIELD']."&comp=".$multi_search[$key]['COMP']."&values=".$multi_search[$key]['VALUE']."&values2=".$multi_search[$key]['VALUE2']."&type_field=".$multi_search[$key]['TYPE_FIELD'];
 						}
-						$link_me_begin.="' target='_blank'>";
+						$link_me_begin.="'>";
 						$link_me_end="</a>";
 					}elseif (isset($link[$key]['RELOAD'])){
 						$link_me_begin="<a href=# OnClick='pag(\"".$link[$key]['RELOAD']."\",\"SHOW_ME\",\"".$form_name."\");'>";
