@@ -9,23 +9,31 @@
 // Please refer to the General Public Licence http://www.gnu.org/ or Licence.txt
 //====================================================================================
 
-function search_profil(){
-	global $l;
-	require_once('require/function_files.php');
-	//$Directory=$_SESSION['OCS']['plugins_dir']."main_sections/";
-	$data=ScanDirectory($_SESSION['OCS']['CONF_PROFILS_DIR'],"txt");
-//	$array_lbl=array("sadmin"=>$l->g(140),"dde_teledeploy"=>$l->g(143),"admin"=>$l->g(141),"ladmin"=>$l->g(142));
-	$i=0;
-	while ($data['name'][$i]){
-	//	echo $Directory.$data['name'][$i]."<br>";
-		if ($data['name'][$i] != '4all_config.txt' and substr($data['name'][$i],-11) == "_config.txt"){	
-			$name=substr($data['name'][$i],0,-11);
-			$temp=read_profil_file($name);
-			$list_profil[$name]=replace_language($temp['INFO']['NAME']);
+function get_profiles() {
+	$profiles = array();
+	$serializer = new XMLProfileSerializer();
+	$profilesRoot = DOCUMENT_REAL_ROOT.'/config/profiles';
+	
+	// Scan and parse each profile file
+	foreach (scandir($profilesRoot) as $file) {
+		$path = $profilesRoot.'/'.$file;
+		$parts = pathinfo($path);
+		
+		// Check if it is an XML file
+		if ($parts['extension'] === 'xml' and is_file($path)) {
+			$profiles[$parts['filename']] = $serializer->unserialize($parts['filename'], file_get_contents($path));
 		}
-		$i++;
-	}	
-	return $list_profil;
+	}
+	
+	return $profiles;
+}
+
+function get_profile_labels() {
+	$labels = array();
+	foreach (get_profiles() as $name => $profile) {
+		$labels[$name] = $profile->getLabelTranslated();
+	}
+	return $labels;
 }
 
 //Function to delete one or an array of user
@@ -45,9 +53,24 @@ function delete_list_user($list_to_delete){
 function add_user($data_user,$list_profil=''){
 	global $l;
 	
-	if (trim($data_user['ID']) == "")
-		$ERROR=$l->g(997);
+	if (isset($data_user['PASSWORD'])){
+		$password = $data_user['PASSWORD'];
+	}
+	$data_user=strip_tags_array($data_user);
 		
+	// Name ok ?
+	if (trim($data_user['FIRSTNAME']) == ""){
+		$ERROR = $l->g(1391).' : '.$l->g(1366);
+	}
+	// Password ok ?
+	if (trim($data_user['PASSWORD']) == "" and trim($data_user['MODIF']) == "" ){
+		$ERROR = $l->g(1391).' : '.$l->g(217);
+	}
+	// Login ok ?
+	if (trim($data_user['ID']) == ""){
+		$ERROR = $l->g(997);
+	}
+	
 	if (is_array($list_profil)){
 		if (!array_key_exists($data_user['ACCESSLVL'], $list_profil))
 			$ERROR=$l->g(998);
@@ -56,7 +79,7 @@ function add_user($data_user,$list_profil=''){
 		$sql="select id from operators where id= '%s'";
 		$arg=$data_user['ID'];
 		$res=mysql2_query_secure($sql, $_SESSION['OCS']["readServer"],$arg);
-		$row=mysql_fetch_object($res);
+		$row=mysqli_fetch_object($res);
 		if (isset($row->id)){
 			if ($data_user['MODIF'] != $row->id){
 				return $l->g(999);
@@ -75,8 +98,9 @@ function add_user($data_user,$list_profil=''){
 								  $data_user['COMMENTS'],
 								  $data_user['USER_GROUP']);
 				if (isset($data_user['PASSWORD']) and $data_user['PASSWORD'] != ''){
-					$sql_update.=",passwd ='%s'";
-					$arg_update[]=md5($data_user['PASSWORD']);
+					$sql_update.=",passwd ='%s' , password_version ='%s' ";
+					$arg_update[]=password_hash($password, constant($_SESSION['OCS']['PASSWORD_ENCRYPTION']));
+					$arg_update[]=$_SESSION['OCS']['PASSWORD_VERSION'];
 				}
 				$sql_update.="	 where ID='%s'";
 				$arg_update[]=$row->id;
@@ -85,8 +109,10 @@ function add_user($data_user,$list_profil=''){
 			}
 		}else{		
 			$sql=" insert into operators (id,firstname,lastname,new_accesslvl,email,comments,user_group";
-			if (isset($data_user['PASSWORD']))
+			if (isset($password)){
 				$sql.=",passwd";
+				$sql.=",password_version";
+			}
 			$sql.=") value ('%s','%s','%s','%s','%s','%s','%s'";
 			
 			$arg=array($data_user['ID'],$data_user['FIRSTNAME'],
@@ -95,9 +121,10 @@ function add_user($data_user,$list_profil=''){
 								  $data_user['EMAIL'],
 								  $data_user['COMMENTS'],
 								  $data_user['USER_GROUP']);
-			if (isset($data_user['PASSWORD'])){
-				$sql.=",'%s'";
-				$arg[]=md5($data_user['PASSWORD']);
+			if (isset($password)){
+					$sql.=",'%s','%s'";
+					$arg[]=password_hash($password, constant($_SESSION['OCS']['PASSWORD_ENCRYPTION']) );
+					$arg[]=$_SESSION['OCS']['PASSWORD_VERSION'];
 			}
 			$sql.=")";
 			mysql2_query_secure($sql, $_SESSION['OCS']["writeServer"],$arg);			
@@ -108,102 +135,96 @@ function add_user($data_user,$list_profil=''){
 }
 
 
-function admin_user($id_user=''){
-	global $protectedPost,$l,$pages_refs; 
-	if ($id_user!='')
-		$update=3;
-	else
-		$update=0;
-		if ($_SESSION['OCS']['CONFIGURATION']['CHANGE_USER_GROUP'] == 'YES'){
-			//search all profil type
-			$list_profil=search_profil();
-			$list_groups_result=look_config_default_values("USER_GROUP_%",'LIKE');
-			if (is_array($list_groups_result['name'])){
-				foreach ($list_groups_result['name'] as $key=>$value){
-					$list_groups[$list_groups_result['ivalue'][$key]]=$list_groups_result['tvalue'][$key];
-				}
-			}
-			$name_field=array("ID","ACCESSLVL","USER_GROUP");
-			$tab_name=array($l->g(995).": ",$l->g(66).":",$l->g(607).":");
-			$type_field= array($update,2,2);	
-			
-		}
-		$name_field[]="FIRSTNAME";
-		$name_field[]="LASTNAME";
-		$name_field[]="EMAIL";
-		$name_field[]="COMMENTS";
-		//$name_field[]="USER_GROUP";
+function admin_user($id_user = null, $is_my_account = false) {
+	global $protectedPost,$l,$pages_refs;
+
+	$tab_hidden = array();
+	$list_groups = array();
 	
-		
-		$tab_name[]=$l->g(49).": ";
-		$tab_name[]=$l->g(996).": ";
-		$tab_name[]=$l->g(1117).": ";
-		$tab_name[]=$l->g(51).": ";
-		//$tab_name[]="Groupe de l'utilisateur: ";
-		
-		
-		$type_field[]= 0; 
-		$type_field[]= 0; 
-		$type_field[]= 0; 
-		$type_field[]= 0; 
-		//$type_field[]= 2; 
-		
-		
-		if ($id_user != '' or $_SESSION['OCS']['CONFIGURATION']['CHANGE_USER_GROUP'] == 'NO'){
-			$tab_hidden['MODIF']=$id_user;
-			$sql="select ID,NEW_ACCESSLVL,USER_GROUP,FIRSTNAME,LASTNAME,EMAIL,COMMENTS from operators where id= '%s'";
-			$arg=$id_user;
-			$res=mysql2_query_secure($sql, $_SESSION['OCS']["readServer"],$arg);
-			$row=mysql_fetch_object($res);
-			if ($_SESSION['OCS']['CONFIGURATION']['CHANGE_USER_GROUP'] == 'YES'){
-				$protectedPost['ACCESSLVL']=$row->NEW_ACCESSLVL;
-				$protectedPost['USER_GROUP']=$row->USER_GROUP;
-				$value_field=array($row->ID,$list_profil,$list_groups);
+	if ($id_user) {
+		$update=3;
+	} else {
+		$update=0;
+	}
+	
+	if ($_SESSION['OCS']['profile']->getConfigValue('CHANGE_USER_GROUP') == 'YES') {
+		//search all profil type
+		$list_profil=get_profile_labels();
+		$list_groups_result=look_config_default_values("USER_GROUP_%",'LIKE');
+		if (is_array($list_groups_result['name'])){
+			foreach ($list_groups_result['name'] as $key=>$value){
+				$list_groups[$list_groups_result['ivalue'][$key]]=$list_groups_result['tvalue'][$key];
 			}
-			$value_field[]=$row->FIRSTNAME;
-			$value_field[]=$row->LASTNAME;
-			$value_field[]=$row->EMAIL;
-			$value_field[]=$row->COMMENTS;
-		}else{
-			if ($_SESSION['OCS']['CONFIGURATION']['CHANGE_USER_GROUP'] == 'YES'){
-				$value_field=array($protectedPost['ID'],$list_profil,$list_groups);
-			}
-			$value_field[]=$protectedPost['FIRSTNAME'];
-			$value_field[]=$protectedPost['LASTNAME'];
-			$value_field[]=$protectedPost['EMAIL'];
-			$value_field[]=$protectedPost['COMMENTS'];				
 		}
-		if ($_SESSION['OCS']['cnx_origine'] == "LOCAL"){
-			$name_field[]="PASSWORD";
-			$type_field[]=0;
-			$tab_name[]=$l->g(217).":";
-			$value_field[]=$protectedPost['PASSWORD'];
-		}
-		$tab_typ_champ=show_field($name_field,$type_field,$value_field);
-		foreach ($tab_typ_champ as $id=>$values){
-			$tab_typ_champ[$id]['CONFIG']['SIZE']=40;
-		}
-		if ($_SESSION['OCS']['CONFIGURATION']['MANAGE_USER_GROUP'] == 'YES'){
-			$tab_typ_champ[2]["CONFIG"]['DEFAULT']="YES";
-		//	$tab_typ_champ[1]['COMMENT_BEHING']="<a href=# onclick=window.open(\"index.php?".PAG_INDEX."=".$pages_refs['ms_admin_profil']."&head=1\",\"admin_profil\",\"location=0,status=0,scrollbars=0,menubar=0,resizable=0,width=550,height=450\")><img src=image/plus.png></a>";
-			$tab_typ_champ[2]['COMMENT_BEHING']="<a href=# onclick=window.open(\"index.php?".PAG_INDEX."=".$pages_refs['ms_adminvalues']."&head=1&tag=USER_GROUP\",\"admin_user_group\",\"location=0,status=0,scrollbars=0,menubar=0,resizable=0,width=550,height=450\")><img src=image/plus.png></a>";
-		}
-		
-		if (isset($tab_typ_champ)){
-			tab_modif_values($tab_name,$tab_typ_champ,$tab_hidden);
-		}	
-		
+		$name_field=array("ID","ACCESSLVL","USER_GROUP");
+		$tab_name=array($l->g(995)." :", $l->g(66)." :", $l->g(607)." :");
+		$type_field= array($update,2,2);
+	}
+	
+	$name_field[]="FIRSTNAME";
+	$name_field[]="LASTNAME";
+	$name_field[]="EMAIL";
+	$name_field[]="COMMENTS";
+	//$name_field[]="USER_GROUP";
+
+	
+	$tab_name[]=$l->g(1366)." :";
+	$tab_name[]=$l->g(996)." :";
+	$tab_name[]=$l->g(1117)." :";
+	$tab_name[]=$l->g(51)." :";
+	//$tab_name[]="Groupe de l'utilisateur: ";
+	
+	
+	$type_field[]= 0; 
+	$type_field[]= 0; 
+	$type_field[]= 0; 
+	$type_field[]= 0; 
+	//$type_field[]= 2; 
+	
+	$tab_hidden['MODIF']=$id_user;
+	$sql="select ID,NEW_ACCESSLVL,USER_GROUP,FIRSTNAME,LASTNAME,EMAIL,COMMENTS from operators where id= '%s'";
+	$arg=$id_user;
+	$res=mysql2_query_secure($sql, $_SESSION['OCS']["readServer"],$arg);
+	$row=mysqli_fetch_object($res);
+	if ($_SESSION['OCS']['profile']->getConfigValue('CHANGE_USER_GROUP') == 'YES'){
+		$protectedPost['ACCESSLVL']=$row->NEW_ACCESSLVL;
+		$protectedPost['USER_GROUP']=$row->USER_GROUP;
+		$value_field=array($row->ID,$list_profil,$list_groups);
+	}
+	$value_field[]=$row->FIRSTNAME;
+	$value_field[]=$row->LASTNAME;
+	$value_field[]=$row->EMAIL;
+	$value_field[]=$row->COMMENTS;
+	
+	if ($_SESSION['OCS']['cnx_origine'] == "LOCAL"){
+		$name_field[]="PASSWORD";
+		$type_field[]=0;
+		$tab_name[]=$l->g(217)." :";
+		$value_field[]=$protectedPost['PASSWORD'];
+	}
+	$tab_typ_champ=show_field($name_field,$type_field,$value_field);
+	foreach ($tab_typ_champ as $id=>$values){
+		$tab_typ_champ[$id]['CONFIG']['SIZE']=40;
+	}
+	if ($_SESSION['OCS']['profile']->getConfigValue('MANAGE_USER_GROUP') == 'YES'){
+		$tab_typ_champ[2]["CONFIG"]['DEFAULT']="YES";
+	//	$tab_typ_champ[1]['COMMENT_AFTER']="<a href=# onclick=window.open(\"index.php?".PAG_INDEX."=".$pages_refs['ms_admin_profil']."&head=1\",\"admin_profil\",\"location=0,status=0,scrollbars=0,menubar=0,resizable=0,width=550,height=450\")><img src=image/plus.png></a>";
+		$tab_typ_champ[2]['COMMENT_AFTER']="<a href=\"index.php?".PAG_INDEX."=".$pages_refs['ms_adminvalues']."&head=1&tag=USER_GROUP\",\"admin_user_group\",\"location=0,status=0,scrollbars=0,menubar=0,resizable=0,width=550,height=450\")><img src=image/plus.png></a>";
+	}
+	
+	if (isset($tab_typ_champ)) {
+		tab_modif_values($tab_name, $tab_typ_champ, $tab_hidden, array(
+			'title' => ($id_user ? ($is_my_account ? $l->g(1365) : $l->g(1385)) : $l->g(1386)),
+			'form_name' => 'my_account'
+		));
+	}	
 }
 
 function admin_profil($form){
 	global $protectedPost,$l,$pages_refs;
 	$yes_no=array('YES'=>$l->g(455),'NO'=>$l->g(454));
-	$telediff_wk=array('LOGIN'=>'LOGIN','USER_GROUP'=>'USER_GROUP','NO'=>$l->g(454));
 	$info_field=array('NAME'=>array('INFO'=>array('LBL'=>$l->g(1153) . ": ",'VALUE'=>'')),
 					  'GUI'=> array('RESTRICTION'=>array('LBL'=>$l->g(1154) . ": ",'VALUE'=>$yes_no)),
-					  'TELEDIFF_WK'=>array('RESTRICTION'=>array('LBL'=>$l->g(1155) . ": ",'VALUE'=>$telediff_wk),
-					  					   'CONFIGURATION'=>array('LBL'=>$l->g(1156) . ": ",'VALUE'=>$yes_no)),
-					  'TELEDIFF_WK_FIELDS'=>array('RESTRICTION'=>array('LBL'=>$l->g(1157) . ": ",'VALUE'=>$yes_no)),
 					  'TELEDIFF_ACTIVATE'=>array('RESTRICTION'=>array('LBL'=>$l->g(1158) . ": ",'VALUE'=>$yes_no)),
 					  'TELEDIFF_VISIBLE'=>array('RESTRICTION'=>array('LBL'=>$l->g(1301) . ": ",'VALUE'=>$yes_no)),
 					  'EXPORT_XML'=>array('RESTRICTION'=>array('LBL'=>$l->g(1305),'VALUE'=>$yes_no)),
@@ -211,8 +232,8 @@ function admin_profil($form){
 					  'MACADD'=>array('ADMIN_BLACKLIST'=>array('LBL'=>$l->g(1159) . ": ",'VALUE'=>$yes_no)),
 					  'SERIAL'=>array('ADMIN_BLACKLIST'=>array('LBL'=>$l->g(1160) . ": ",'VALUE'=>$yes_no)),
 					  'IPDISCOVER'=>array('ADMIN_BLACKLIST'=>array('LBL'=>$l->g(1161) . ": ",'VALUE'=>$yes_no),
-					  'CONFIGURATION'=>array('LBL'=>$l->g(1172) . ": ",'VALUE'=>$yes_no)),
-				          'TELEDIFF'=>array('CONFIGURATION'=>array('LBL'=>$l->g(1162) . ": ",'VALUE'=>$yes_no)),
+					  					'CONFIGURATION'=>array('LBL'=>$l->g(1172) . ": ",'VALUE'=>$yes_no)),
+				      'TELEDIFF'=>array('CONFIGURATION'=>array('LBL'=>$l->g(1162) . ": ",'VALUE'=>$yes_no)),
 					  'CONFIG'=>array('CONFIGURATION'=>array('LBL'=>$l->g(1163) . ": ",'VALUE'=>$yes_no)),
 					  'GROUPS'=>array('CONFIGURATION'=>array('LBL'=>$l->g(1164) . ": ",'VALUE'=>$yes_no)),
 					  'CONSOLE'=>array('CONFIGURATION'=>array('LBL'=>$l->g(1165) . ": ",'VALUE'=>$yes_no)),
@@ -230,7 +251,7 @@ function admin_profil($form){
 					   'RESTRICTION'=>$l->g(1175),
 					   'ADMIN_BLACKLIST'=>$l->g(1176),
 					   'CONFIGURATION'=>$l->g(1177));
-	if ($protectedPost['Valid_modif_profil_x']){
+	if ($protectedPost['Valid_modif_profil']){
 		//read profil file
 		$forprofil=read_profil_file($protectedPost['PROFILS']);
 		//read all profil value
@@ -255,9 +276,9 @@ function admin_profil($form){
 		msg_success($l->g(1274));	
 	}
 	
-	$array_profil=search_profil();
+	$array_profil=get_profile_labels();
 	echo $l->g(1196). ": " .show_modif($array_profil,"PROFILS",2,$form);
-	echo "<a href=# onclick=window.open(\"index.php?".PAG_INDEX."=".$pages_refs['ms_new_profil']."&head=1&form=".$form."\",\"new_profil\",\"location=0,status=0,scrollbars=0,menubar=0,resizable=0,width=650,height=550\")><img src=image/plus.png></a>";
+	echo "<a href=\"index.php?".PAG_INDEX."=".$pages_refs['ms_new_profil']."&head=1&form=".$form."\"><img src=image/plus.png></a>";
 	
 	if (isset($protectedPost['PROFILS']) and $protectedPost['PROFILS'] != ''){
 		$forall=read_config_file();			
@@ -293,7 +314,9 @@ function admin_profil($form){
 						}				
 				}
 				$tab_typ_champ=show_field($name_field,$type_field,$value_field);
-				tab_modif_values($tab_name,$tab_typ_champ,$tab_hidden,$title="",$comment="",$name_button="modif_profil");	
+				tab_modif_values($tab_name,$tab_typ_champ,$tab_hidden, array(
+					'button_name' => 'modif_profil'
+				));
 				
 			}elseif ($protectedPost['cat'] == 'PAGE_PROFIL'){
 				$champs="<table align=center><tr><td align=center>";
@@ -311,13 +334,35 @@ function admin_profil($form){
 					}
 				}
 				$champs.="</td></tr></table>";		
-				tab_modif_values($champs,'','','','',$name_button="modif_profil");		
+				tab_modif_values($champs,array(),array(), array(
+					'button_name' => 'modif_profil'
+				));
 			}
 		}		
 	}
 	
 }
 
+function updatePassword($id_user,$password){
+	$sql="select id from operators where id= '%s'";
+	$arg=$id_user;
+	$res=mysql2_query_secure($sql, $_SESSION['OCS']["readServer"],$arg);
+	$row=mysqli_fetch_object($res);
+	if (isset($row->id)){
+		if (isset($password) and $password != ''){
+			$sql_update="update operators set passwd ='%s', PASSWORD_VERSION ='%s' ";
+			$newhash = password_hash($password,constant($_SESSION['OCS']['PASSWORD_ENCRYPTION']));
+			// if constant don't exist, or encryption not good
+			if(!empty($newhash)){
+				$arg_update[]=$newhash;
+				$arg_update[]=$_SESSION['OCS']['PASSWORD_VERSION'];
+				$sql_update.="	 where ID='%s'";
+				$arg_update[]=$row->id;
+				$res = mysql2_query_secure($sql_update, $_SESSION['OCS']["writeServer"],$arg_update);
+			}
+		}
+	}
+}
 
 
 ?>
