@@ -665,8 +665,8 @@ then
     res=0
     while [ $res -eq 0 ]
     do
-        echo "Communication server can create detailled logs. This logs can be enabled"
-        echo "by setting interger value of LOGLEVEL to 1 in Administration console"
+        echo "Communication server can create detailed logs. This logs can be enabled"
+        echo "by setting integer value of LOGLEVEL to 1 in Administration console"
         echo "menu Configuration."
         echo -n "Where to put Communication server log directory [$OCS_COM_SRV_LOG] ?"
         read ligne
@@ -749,6 +749,7 @@ then
     COMPRESS_ZLIB=0
     XML_SIMPLE=0
     NET_IP=0
+    SOAP_LITE=0
     echo "Checking for DBI PERL module..."
     echo "Checking for DBI PERL module" >> $SETUP_LOG
     $PERL_BIN -mDBI -e 'print "PERL module DBI is available\n"' >> $SETUP_LOG 2>&1
@@ -815,6 +816,30 @@ then
     else
         echo "Found that PERL module Net::IP is available."
     fi
+    # Check for SOAP::Lite   
+    echo "Checking for SOAP::Lite Perl module..."
+    echo "Checking for SOAP::Lite Perl module" >> $SETUP_LOG
+    $PERL_BIN -mSOAP::Lite -e 'print "PERL module SOAP::Lite is available\n"' >> $SETUP_LOG 2>&1
+    if [ $? -ne 0 ]
+    then
+        echo "*** ERROR: PERL module SOAP::Lite is not installed !"
+        REQUIRED_PERL_MODULE_MISSING=1
+        SOAP_LITE=1
+    else
+        echo "Found that PERL module SOAP::Lite is available."
+    fi
+    # Check for Zip::Archive
+    echo "Checking for Archive::Zip Perl module..."
+    echo "Checking for Archive::Zip Perl module" >> $SETUP_LOG
+    $PERL_BIN -mArchive::Zip -e 'print "PERL module Archive::Zip is available\n"' >> $SETUP_LOG 2>&1
+    if [ $? -ne 0 ]
+    then
+        echo "*** ERROR: PERL module Archive::Zip is not installed !"
+        REQUIRED_PERL_MODULE_MISSING=1
+        Archive_Zip=1
+    else
+        echo "Found that PERL module Archive::Zip is available."
+    fi
     if [ $REQUIRED_PERL_MODULE_MISSING -ne 0 ]
     then
         echo "*** ERROR: There is one or more required PERL modules missing on your computer !"
@@ -940,28 +965,6 @@ then
     echo "| Checking for optional Perl Modules...                    |"
     echo "+----------------------------------------------------------+"
     echo
-    echo "Checking for SOAP::Lite PERL module..."
-    echo "Checking for SOAP::Lite PERL module" >> $SETUP_LOG
-    $PERL_BIN -mSOAP::Lite -e 'print "PERL module SOAP::Lite is available\n"' >> $SETUP_LOG 2>&1
-    if [ $? -ne 0 ]
-    then
-        echo "*** Warning: PERL module SOAP::Lite is not installed !"
-        echo "This module is only required by OCS Inventory NG SOAP Web Service."
-        echo -n "Do you wish to continue ([y]/n] ?"
-        read ligne
-        if [ -z "$ligne" ] || [ "$ligne" = "y" ]
-        then
-            echo "User choose to continue setup without PERL module SOAP::Lite" >> $SETUP_LOG
-        else
-            echo
-            echo "Installation aborted !"
-            echo "User choose to abort installation !" >> $SETUP_LOG
-            exit 1
-        fi
-    else
-        echo "Found that PERL module SOAP::Lite is available."
-    fi
-    echo
     echo "Checking for Apache2::SOAP PERL module..."
     echo "Checking for Apache2::SOAP PERL module" >> $SETUP_LOG
     $PERL_BIN -mApache2::SOAP -e 'print "PERL module Apache2::SOAP is available\n"' >> $SETUP_LOG 2>&1
@@ -1239,14 +1242,14 @@ then
     fi
     echo
     echo "+----------------------------------------------------------+"
-    echo "| OK, Communication server setup sucessfully finished ;-)  |"
+    echo "| OK, Communication server setup sucessfuly finished ;-)  |"
     echo "|                                                          |"
     echo "| Please, review $APACHE_CONFIG_DIRECTORY/$COM_SERVER_APACHE_CONF_FILE"
     echo "| to ensure all is good. Then restart Apache daemon.       |"
     echo "+----------------------------------------------------------+"
     echo
     echo "Leaving Apache directory" >> $SETUP_LOG
-    echo "Communication server installation successfull" >> $SETUP_LOG
+    echo "Communication server installation successful" >> $SETUP_LOG
 fi
 
 echo
@@ -1274,7 +1277,7 @@ then
     echo "root document directory."
     echo "If you choose to move directory, YOU MUST MOVE 'download' directory to"
     echo "Administration Server writable/cache directory (by default"
-    echo "$ADM_SERVER_VAR_DIR), especialy if you use deployement feature."
+    echo "$ADM_SERVER_VAR_DIR), especially if you use deployment feature."
     echo
     echo -n "Do you wish to continue ([y]/n)?"
     read ligne
@@ -1302,7 +1305,7 @@ then
     echo "OK, using directory $ADM_SERVER_STATIC_DIR to install static files ;-)"
     echo "Using directory $ADM_SERVER_STATIC_DIR for static files" >> $SETUP_LOG
     echo
-    echo "Where to create writable/cache directories for deployement packages,"
+    echo "Where to create writable/cache directories for deployment packages,"
     echo -n "administration console logs, IPDiscover and SNMP [$ADM_SERVER_VAR_DIR] ?"
     read ligne
     if test -z $ligne
@@ -1407,6 +1410,14 @@ then
     echo "Fixing permissions on directory $ADM_SERVER_STATIC_DIR/$ADM_SERVER_STATIC_REPORTS_DIR" >> $SETUP_LOG
     # Set PHP pages directory owned by root, group Apache
     chown -R root:$APACHE_GROUP $ADM_SERVER_STATIC_DIR/$ADM_SERVER_STATIC_REPORTS_DIR >> $SETUP_LOG 2>&1
+    # Set "download/" "upload/" "plugins/main_section" "plugins/computer_detail" "plugins/language" "config/" own to apache
+    chown -R $APACHE_USER:$APACHE_GROUPE $ADM_SERVER_STATIC_DIR/$ADM_SERVER_STATIC_REPORTS_DIR/config >> $SETUP_LOG 2>&1
+    chown -R $APACHE_USER:$APACHE_GROUPE $ADM_SERVER_STATIC_DIR/$ADM_SERVER_STATIC_REPORTS_DIR/plugins/computer_detail >> $SETUP_LOG 2>&1
+    chown -R $APACHE_USER:$APACHE_GROUPE $ADM_SERVER_STATIC_DIR/$ADM_SERVER_STATIC_REPORTS_DIR/plugins/main_sections >> $SETUP_LOG 2>&1
+    chown -R $APACHE_USER:$APACHE_GROUPE $ADM_SERVER_STATIC_DIR/$ADM_SERVER_STATIC_REPORTS_DIR/plugins/language >> $SETUP_LOG 2>&1
+    chown -R $APACHE_USER:$APACHE_GROUPE $ADM_SERVER_STATIC_DIR/$ADM_SERVER_STATIC_REPORTS_DIR/download >> $SETUP_LOG 2>&1
+    chown -R $APACHE_USER:$APACHE_GROUPE $ADM_SERVER_STATIC_DIR/$ADM_SERVER_STATIC_REPORTS_DIR/upload >> $SETUP_LOG 2>&1
+    
     if [ $? -ne 0 ]
     then
         echo "*** ERROR: Unable to set permissions on $ADM_SERVER_STATIC_DIR/$ADM_SERVER_STATIC_REPORTS_DIR, please look at error in $SETUP_LOG and fix !"
@@ -1662,6 +1673,14 @@ then
     echo "Writing Administration server configuration to file $APACHE_CONFIG_DIRECTORY/$ADM_SERVER_APACHE_CONF_FILE"
     echo "Writing communication server configuration to file $APACHE_CONFIG_DIRECTORY/$ADM_SERVER_APACHE_CONF_FILE" >> $SETUP_LOG
     cp -f $ADM_SERVER_APACHE_CONF_FILE.local $APACHE_CONFIG_DIRECTORY/$ADM_SERVER_APACHE_CONF_FILE >> $SETUP_LOG 2>&1
+    
+    #Fix permissions on server side for plugin engine (perl / plugins) dir usualy in etc/ocsinventory-server..
+    
+    # Where are located OCS Communication server plugins configuration files
+	chown -R $APACHE_USER:$APACHE_GROUPE $OCS_COM_SRV_PLUGINS_CONFIG_DIR
+	# Where are located OCS Communication server plugins perl files 
+	chown -R $APACHE_USER:$APACHE_GROUPE $OCS_COM_SRV_PLUGINS_PERL_DIR
+    
     if [ $? -ne 0 ]
     then
         echo "*** ERROR: Unable to write $APACHE_CONFIG_DIRECTORY/$ADM_SERVER_APACHE_CONF_FILE, please look at error in $SETUP_LOG and fix !"
@@ -1680,7 +1699,7 @@ then
     echo "| to configure database server and create/update schema.   |"
     echo "+----------------------------------------------------------+"
     echo
-    echo "Administration server installation successfull" >> $SETUP_LOG
+    echo "Administration server installation successful" >> $SETUP_LOG
 fi
 
 echo
